*aeanalysis.do
# delimit;
clear;
capture log close;
log using ../log/adultequivalent.log, replace;
clear;
set memory 30m;
set more off;
use ../../profile/dta/povertyprofile.dta;
merge hhnumber using ../../profile/dta/householdinformation.dta;
tabulate _merge;
drop _merge;
keep if oversample==0;
label define aepoor   0 "Non-Poor" 100 "Poor";

/***   POVERTY LINE *** we use the same poverty line defined 
in ../../do/povertyprofile.do *************************/
/*For the computation of adult equivalent, please see the Appendix A of
 World Bank (2000) Making Transition Work For Everyone World Bank: Washinton D
c.*/

 
forvalues i = 0/10 {
local s = `i' * 5 + 50;
scalar theta = `s' / 100;
generate eqsize`s'= hhsize_resident ^ theta;
generate aeexp_d_`s'  = exptot_d / eqsize`s';
};

generate eqsize_oecd_old = 0.3 + nadult_resident * 0.7 + nchild_resident * 0.5;
generate eqsize_oecd_new = 0.5 + nadult_resident * 0.5 + nchild_resident * 0.3;
generate aeexp_d_oecd_old = exptot_d / eqsize_oecd_old;
generate aeexp_d_oecd_new = exptot_d / eqsize_oecd_new;

local suffixlist = "50 55 60 65 70 75 80 85 90 95 100 oecd_old oecd_new";

tokenize `suffixlist';

while "`1'" != "" {;
generate aepoor_d_`1' = 100 * (aeexp_d_`1' <= povertyline);
summarize aepoor_d_`1'[fw=hhsize_resident];
macro shift;
};



 

capture program drop aeout;
program define aeout;
local var `1';
local fname "`2'";
local suffixlist = "50 55 60 65 70 75 80 85 90 95 100 oecd_old oecd_new";
tokenize "`suffixlist'";
local labname :value label `var';
tabulate `var', matcell(tmp) matrow(tmp2);
local vals = rowsof(tmp) ;
local rsize = `vals' +1;
matrix define out = J(`rsize',14,-10);
matrix out[1,1] = tmp2;
matrix list out;

scalar k = 2;
while "`1'" != "" {;
quietly tabulate `var' aepoor_d_`1' [fw=hhsize_resident], matcell(tmp);
display "`1'";
scalar tot0 = 0;
scalar tot1 = 0;
forvalues i = 1/`vals' {;
scalar tot0 = tot0 + tmp[`i',1];
scalar tot1 = tot1 + tmp[`i',2];
scalar pr = tmp[`i',2]/(tmp[`i',1] + tmp[`i',2]);
display pr;
matrix out[`i', k] = pr;
};
scalar pr = tot1 / (tot0+tot1);
matrix out[`rsize', k] = pr; *Total;
scalar k= k+1;
macro shift;
};
preserve;
drop *;
svmat out;
tokenize "`suffixlist'";
forvalues i=1/14 {;
if `i' ==1 {;
rename out`i' value;
};
else {;
rename out`i' ae_`1';
format ae_`1' %9.7f;
macro shift;
};
};
generate lab = value;
label define `labname' -10 "Total", add;
label values lab `labname' ;
order lab value;
drop value;
list;
display "`fname'";
outsheet using ../out/`fname'.txt , replace;
restore;
end;

aeout loc_type ae_location;
aeout hhs ae_hhs; 
aeout hh_child ae_nchild;

save ../dta/adultequivalent.dta, replace;
log close;
exit, clear;
