#delimit;
*Calculate the amount of service each household receives;

capture log close;
log using ../log/durableaggregate.log, replace;
set more off;
set memory 20m;
use ../../datacheck/dta/r9_1.dta;
drop if a_have==2;
tabulate assetcod a_have;
sort assetcod;
replace a_when_aq=. if a_when_aq<0;
replace a_res_vl=. if a_res_vl<0;
generate age = 2001-a_when_aq;

/*Firstly we compute the life span and estimated remaining life time
of each good. The way we do is to compute the mean age and set the
life span of each asset at the twice the mean age. This is based
upon the assumption that replacement of durables occurs uniformly
over time.*/;
by assetcod: egen mage= mean(age);
generate lifespan = mage*2;
tabulate assetcod, sum(lifespan);
generate rem = lifespan - age;
generate val = a_res_vl;
generate useval = val / (rem * 12);
tabulate assetcod, sum(useval);
sort assetcod;
by assetcod: egen mval  = mean(useval);
by assetcod: egen sval  = sd(useval);
by assetcod: egen medval= median(useval);
/*If the remaining life time is less than 1 year, we assume no value*/;
replace useval = 0 if useval <0 | useval ==. | rem < 1;
/*We also eliminate extreme use values*/;
replace useval = medval if (useval > mval + sval*5 | useval < mval - sval*5) & useval != 0;

table assetcod, c(freq mean lifespan mean useval); 

replace useval = useval * a_number;
sort hhnumber;
collapse (sum) useval, by (hhnumber);
sort hhnumber;
merge hhnumber using ../../consumption/dta/strata.dta;
tab _merge;
keep useval hhnumber;
replace useval =0 if useval ==.;
sum useval, detail;
sort hhnumber;
save ../dta/durableaggregate.dta, replace;
log close;
exit,clear;


