#delimit;
clear;
capture log close;
log using ../log/rentaggregate.log, replace;
set more off;
set memory 20m;
use ../../consumption/dta/strata.dta;
sort hhnumber;
merge hhnumber using ../../datacheck/dta/r4.dta;
tabulate _merge;
drop _merge;
sort hhnumber;
merge hhnumber using ../../consumption/dta/houseaggregate.dta;
tabulate _merge;
drop _merge;
replace d_rent=. if d_rent<0;
replace val_rent=. if val_rent<0;
replace val_rent=. if val_rent >=400;
count if d_rent!=. & val_rent!=.;
generate obsrent = d_rent;
generate own =0;
replace own = 1 if  rent_sta==1;
replace obsrent = val_rent if obsrent==.;
label variable obsrent "Observed rent; self-reported by owners+reported by renters";
tabulate own, summarize(rent);

xi:sw reg obsrent i.distr i.loc_type expdhea expelec exphgas expo_en expwat exph_fee area_dw area_hh n_rooms own i.garbage i.typ_wc i.mat_dwng i.excl_wc i.loc_wc i.q_garage i.typ_wast i.loc_h2o i.g_noise, pr(0.05);
predict predicted_rent;
count if predicted_rent<0;
/*Self-reporting bias corrected rent estimate*/
replace own=0;
predict rent_corrected;
count if rent_corrected<0;
replace rent_corrected = 0 if rent_corrected <0;
generate rent = d_rent;
replace  rent = rent_corrected if d_rent ==.;
label variable rent "Rent used in analysis, estimated+observed, self-reporting bias correction"; 
label variable predicted_rent "Predicted rent with self-reporting dummy";
label variable rent_corrected "Predicted rent with self-reporting bias correction";
label variable d_rent "Reported Rent--renters only";
label variable val_rent "Self-reported Rent--owners only";

sum predicted_rent, detail; 
sum rent_corrected, detail;
sum d_rent, detail;
sum val_rent, detail; 

generate typwc2   = (typ_wc  ==2);
generate gnoise2  = (g_noise ==2);
generate matdwng3 = (mat_dwng==3);
generate matdwng5 = (mat_dwng==5);
generate locwc3   = (loc_wc  ==3);
generate garbage2 = (garbage ==2);


xi:reg rent i.distr typwc2 expdhea expelec gnoise2 matdwng3 matdwng5 exph_fee area_dw locwc3 n_rooms garbage2; 
predict predicted_rent2;
count if predicted_rent2 <0;
replace predicted_rent2 =0 if predicted_rent2 <0;
label variable predicted_rent2 "Predicted rent without self-reporting dummy";
generate rent2 = obsrent;
replace  rent2 = predicted_rent2 if rent2 ==.;
label variable rent2 "Rent used in analysis, estimated+observed, no self-reporting bias correction"; 

sum rent, detail;
sum rent2, detail;
keep hhnumber rent rent2;
sort hhnumber;


save ../dta/rentaggregate.dta, replace;
log close;
exit,clear;




