#delimit ;
capture log close;
	log using K:/BIHS01/Data/STATA/CONSUMPTION/Log/AdjustedPercapitaConsumption.log, replace;
clear;
	set more off;
	set memory 20m;
use K:/BIHS01/Data/STATA/CONSUMPTION/DTA/AdjustedTotalAggregate.dta;
sum;
keep hhnumber expfood expnfood exptot exptot_d exptot_n;

** For now use the Pc and Ae Variable
;
merge hhnumber using K:/BIHS01/Data/STATA/CONSUMPTION/DTA/HouseholdSize.dta;
tab _merge;
	drop _merge;

label define decile
        1  "decile 1"
        2  "decile 2"
        3  "decile 3"
        4  "decile 4"
        5  "decile 5"
        6  "decile 6"
        7  "decile 7"
        8  "decile 8"
        9  "decile 9"
        10 "decile10"
;

capture program drop pc_ae_variables;
program define pc_ae_variables;
	while "`1'" != "" {
		  local type `1';
if ("`1'" == "0") {local type "";};
generate pcexp`type'  = exptot`type'  / hhsize_resident;
label variable pcexp`type'   "Per Capita - Total Expenditure - Res";
format pcexp`type' %10.2f;

generate aeexp`type'   = exptot`type'  / adulteq;
label variable aeexp`type'   "Adult Equiv - Total Expenditure - Res";
format aeexp`type' %10.2f;

summarize;

** Calculate deciles of households based on the PC expenditure
   As usual, the ranking is done for Hhs and the variables used
   is the Pc expenditure.  All poverty measured involving individuals 
   should be calculated using size weights
;
summarize pcexp`type',detail;    /* Notice the outlier excluded later */
sort pcexp`type';
generate hhdecpc`type'=group(10) ;
label variable hhdecpc`type' "Hh level Pc Exp. Decile";

sort aeexp`type';
generate hhdecae`type'=group(10) ;
label variable hhdecae`type' "Hh level Ae Exp. Decile";

label values hhdecpc`type' decile;
label values hhdecae`type' decile;

** Get few tables on Per capita basis
;
tab hhdecpc`type', sum(hhsize_resident);
tab hhdecpc`type', sum(hhsize_all) ;
tab hhdecpc`type' [w=hhsize_resident], sum(pcexp`type') ;
tab hhdecpc`type' [w=hhsize_resident], sum(aeexp`type') ;
tab hhsize_resident, sum(pcexp`type');

** Get few tables on Adult Equivalent basis
;
tab hhdecae`type', sum(hhsize_resident);
tab hhdecae`type', sum(hhsize_all) ;
tab hhdecae`type' [w=hhsize_resident], sum(aeexp`type') ;
tab hhdecae`type' [w=hhsize_resident], sum(pcexp`type') ;

** Calculate deciles of individuals based on the PC expenditure
   The ranking is done for Hhs adding up the number of people in 
   each household and the variables used is the Pc expenditure.  
   Even in this case poverty measured involving individuals should be 
   calculated using Hhsize as weights
;
sort pcexp`type';
gen poppc`type'=sum(hhsize_resident) ;
sum poppc`type';
local pmin=_result(5);
local pmax=_result(6);
local pint=int(`pmax'/10);
gen popdecpc`type'=autocode(poppc`type',10,`pmin',`pmax');
replace popdecpc`type'=int(popdecpc`type'/`pint');
label variable popdecpc`type' "Pop level Pc Exp. Decile";

sort aeexp`type';
gen popae`type'=sum(hhsize_resident) ;
sum popae`type';
local pmin=_result(5);
local pmax=_result(6);
local pint=int(`pmax'/10);
gen popdecae`type'=autocode(popae`type',10,`pmin',`pmax');
replace popdecae`type'=int(popdecae`type'/`pint');
label var popdecae`type' "Pop level Ae Exp. Decile";

label values popdecpc`type' decile;
label values popdecae`type' decile;

drop poppc`type' popae`type';
macro shift;
};
end;
	
pc_ae_variables "_d" "0" "_n";
** SAVE THE FILE
;
lab data "Per Capita expenditure: deflated";
sort hhnumber;
save K:/BIHS01/Data/STATA/CONSUMPTION/DTA/AdjustedPercapitaConsumption.dta, replace;
log close;
exit, clear;



