*DistrictPriceIndex.do
*!Version
#delimit ;
capture log close;
log using K:/BIHS01/Data/STATA/CONSUMPTION/LOG/DistrictPriceIndex.log, replace;
clear;
set memory 20m;	
set more off;
set trace off;
** There are regional differences in the cost of living, and 
therefore a regional price index is needed to correct for the fact 
that HHs experience different prices in different areas. The BIHS-01
provides data on over 78 food items for the sampled households, 
using which one can construct unit values. However, the construction of
price index for non-food item is not that easy because the non-food items
are too heterogenous for a unit value to be meaningful. As a first step we 
will first construct a regional food price index;

********* METHODOLOGY FOR FOOD PRICE INDEX ***;

**** STEP 1: From the entire national sample of population ranked by the 
nominal per capita expenditure, a sub-sample of botom 40% is identified as
the reference group of population. Only data from this sub-sample are used 
for the construction of the food price index (Use bot40);

**** STEP 2: The selected sub-sample is allocated to the rural and urban 
locality of the nine districts, which defines the reference group of population
for each of the district and locality.;

use K:/BIHS01/Data/STATA/CONSUMPTION/Dta/PerCapitaConsumption;
gen bot40 = (popdecpc <= 4);
keep hhnumber bot40 popdecpc hhsize_resident;
tempfile bot40;
sort hhnumber;
save `bot40';


use K:/BIHS01/Data/STATA/CONSUMPTION/Temp/FoodTemporary.Dta;	
drop if g_item ==.;
keep hhnumber quant totexp totfood g_item;

sort hhnumber;
merge hhnumber using K:/BIHS01/Data/STATA/CONSUMPTION/Dta/Strata.dta;
tab _merge;
drop if _merge != 3;	
drop _merge;

sort hhnumber;
merge hhnumber using `bot40';
tab _merge;
drop _merge;
tab popdecpc [w=hhsize_resident];
tab distr loc_typ [w=hhsize_resident] if bot40==1;
drop if bot40 !=1;

sort hhnumber;
merge hhnumber using K:/BIHS01/Data/STATA/CONSUMPTION/Dta/PerCapitaConsumption.dta;
tab _merge;
drop if _merge != 3;	
drop _merge;

***STEP 3: For sake of homogeneity, we have classified the 78 food items into
7 food groups. This aggregation also takes care of the problem of having too
few observations fro some food items for the reference group of population;

gen fditem=1 if g_item==1;
replace fditem=2 if g_item==2 | g_item==3;
replace fditem=3 if g_item==4 | g_item==5;
replace fditem=4 if g_item==6 | g_item==7;
replace fditem=5 if g_item==8;
replace fditem=6 if g_item==9;
label variable fditem "food-groups";
capture program drop aggregateitem;
program define aggregateitem;
while "`1'" != "" {
	local itemnumber `1';
   macro shift;
	local itemname `1';
	macro shift;
	local itemlabel `1';
		macro shift;
		sort hhnumber;
	by hhnumber: egen fd_`itemname'_amt = sum(totexp) if fditem == `itemnumber'; 
	by hhnumber: egen fd_`itemname'_qty = sum(quant) if fditem == `itemnumber'; 
		label variable fd_`itemname'_amt `"`itemlabel' money amount"';
		label variable fd_`itemname'_qty `"`itemlabel' quantity"';
};
end;
aggregateitem 1 cereal "cereal" 2 fruitvegi "fruits & Veg" 3 meatdairy "Meats & Dairy" 4 fatssugars "Fats & sugars" 5 others "Others" 6 alcohol "alcohol";

sort hhnumber fditem;
by hhnumber fditem: generate temp = _n;
drop if temp != 1;
drop temp;


***** CONSTRUCTION OF REGIONAL PRICE INDECES;

**** Step 4: select the sub-sample-which is the botton 40 percentile of
the population decile;
sort hhnumber;

** there are some 2931 individuals in the bottom 40 percentile of the
population-which is the reference group;

*** step 5: calculate the mean price by food item groups(g_item), for the
sub-sample, in each of the nine regions seperately. Then, we will
take the ratio of the average regional price to national(sub-sample) average 
price by food group items -call it price ratio;

keep if bot40==1 & g_item!=.;
tab distr;
*** make 5 food-groups so that it is comparable with the food groups
we have created in the expenditure files-HHEXPTLS;

capture program drop aggregatehousehold;
program define aggregatehousehold;
while "`1'" != "" {
	  local itemname `1';
	macro shift;
	sort hhnumber;
	by hhnumber: egen temp_amt = sum(fd_`itemname'_amt);
	replace fd_`itemname'_amt = temp_amt;
	by hhnumber: egen temp_qty = sum(fd_`itemname'_qty);
	replace fd_`itemname'_qty = temp_qty;
	drop temp_amt temp_qty;
	};
end;
aggregatehousehold cereal fruitvegi meatdairy fatssugars others alcohol; 
rename fd_alcohol_qty nfd_alcohol_qty;
rename fd_alcohol_amt nfd_alcohol_amt;
sort hhnumber;
by hhnumber : generate temp = _n;
drop if temp != 1;
drop temp;

**FOR THE REFERENCE GROUP ONLY;
** get the mean price in the nation-by food items;
	/*The following line is problematic, though this is what they did
	  in 1995; It makes no sense to add, for example, the quantity of apples
	and pears. The problem is more serious when you add things measured
	  in different units such as kg and l(This is the case for fgitem 2);*/

	

*label variable mprice "qty weighted-mean national price by food item";

** get the mean price of food groups by regions;

** get the price ratio by food items-regional to national;

** get a table to calculate the budget shares-this will be done in
excel tables once we have the total expenditures on food groups.; 



	
/*Price Indices for non food*/
*** In the non-food items we find that we don't have prices for most
of the non-food items. For the non-food items that we do have prices, 
it only constitutes about one third of the non-food expenditure. So we do have
a problem. One way might be to scale the non-food expenditures by a 
proportion (=2.75) so that it becomes equal to 100. The non-food 
items ( 5 items) for which we have prices are as follows: 

Alcohol
Tobacco, 
personal, 
cleaning, and
gasoline.

The methodology for calculating the non-food price index 
will be the same as that of the food price index;
;

********* NON-FOOD PRICE INDEX ***;

**** STEP 1: From the entire national sample of population ranked by the 
nominal per capita expenditure, a sub-sample of botom 40% is identified as
the reference group of population. Only data from this sub-sample are used 
  for the construction of the food price index This part is already done
when calculating food price index.;

**** STEP 2: The selected sub-sample is allocated to the rural and urban 
locality of the nine regions, which defines the reference group of population
for each of the region and locality-However, for the time being we will not
do for sectors within regions;

***STEP 3: For sake of homogeneity, we have classified the non-food items into
5 food groups. This aggregation also takes care of the problem of having too
few observations for some non-food items for the reference group of population;

***** CONSTRUCTION OF REGIONAL PRICE INDECES;

**** Step 4: select the sub-sample-which is the botton 40 percentile of
the population decile;

*** step 5: calculate the mean price by food item groups(g_item), for the
sub-sample, in each of the nine regions seperately. Then, we will
take the ratio of the average regional price to national(sub-sample) average 
price by food group items -call it price ratio;

sort hhnumber;
merge hhnumber using K:/BIHS01/Data/STATA/CONSUMPTION/Temp/NonfoodTemporary.dta;
tab _merge;
drop if _merge !=3;
drop _merge;

tab distr;
*** select the 5 nonfood-groups for which we have prices;
capture program drop aggregate_group_amt_qty;
program define aggregate_group_amt_qty;
	local group `1';
   macro shift;
   local label `1';
	generate nfd_`group'_qty = 0;
   generate nfd_`group'_amt = 0;
   label variable nfd_`group'_qty `"`label' quantity"';
   label variable nfd_`group'_amt `"`label' amount"';
   macro shift;
   while "`1'" != ""{
local item `1';
		  replace nfd_`group'_qty = nfd_`group'_qty + qty_`item';
		  replace nfd_`group'_amt = nfd_`group'_amt + amt_`item';
	macro shift;
};
end;

aggregate_group_amt_qty tobacco "tobacco" cigarette;
aggregate_group_amt_qty personalitem "personal" toisoap luxtoisoap shampoo conditioner shampcond hndbdycream lotion facecream cleansingcream deodrant toothpaste haircut; /*Hygine and membership not included*/
aggregate_group_amt_qty  cleaning "cleaning" washsoap madesoap washingpowder bleach dishwash othwash;
aggregate_group_amt_qty gasoil "gasoline" gasoil;


/* if the price is five times greater than mean plus sd * 5, then replace it with the median for gas oil whose prices are not treated to get rid of outliers*/
generate nfd_gasoil_price = nfd_gasoil_amt / nfd_gasoil_qty;
egen sd = sd(nfd_gasoil_price);
egen mean = mean(nfd_gasoil_price);
sum nfd_gasoil_price; 
egen nfd_gasoil_median_amt=median(nfd_gasoil_amt) if nfd_gasoil_amt >0;
egen nfd_gasoil_median_qty=median(nfd_gasoil_qty)  if nfd_gasoil_amt >0;;
replace nfd_gasoil_amt = nfd_gasoil_median_amt if nfd_gasoil_price > mean + sd * 5 & nfd_gasoil_amt != . & nfd_gasoil_price > mean * 5;
replace nfd_gasoil_qty = nfd_gasoil_median_qty if nfd_gasoil_price > mean + sd * 5 & nfd_gasoil_qty != . & nfd_gasoil_price > mean * 5;
drop nfd_gasoil_median_amt nfd_gasoil_median_qty sd mean;

capture program drop calculate_price;
program define calculate_price;
while "`1'" != "" {
local group `1';
** get the mean price in the nation-by food items;
egen `group'_mqty = sum(`group'_qty);
egen `group'_mamt = sum(`group'_amt);
generate `group'_mprice = `group'_mamt / `group'_mqty;
display ("bakabaka");
** get the mean price of non-food groups by districts;
egen `group'_ramt=sum(`group'_amt), by(distr loc_typ);
egen `group'_rqty=sum(`group'_qty), by(distr loc_typ);
generate `group'_regprice=`group'_ramt/`group'_rqty;
generate `group'_pratio=`group'_regprice/`group'_mprice;
sort distr loc_typ;
	by distr loc_typ:sum	`group'_amt `group'_qty `group'_pratio;
*** get the price ratio-the ratio of average price of a food group 
in a region to the national price(of sub-sample);
drop `group'_mamt `group'_mqty `group'_ramt `group'_rqty;
sum `group'_mprice;
tabulate distr, sum(`group'_regprice) means freq;
tabulate distr, sum(`group'_pratio) means freq;
	sort loc_typ;
by loc_typ:tabulate distr, sum(`group'_pratio) means freq;
by loc_typ:tabulate distr, sum(`group'_regprice) means freq;
	by loc_typ:tabulate distr, sum(`group'_mprice) means freq;
egen `group'_tall=sum(`group'_amt);
summarize `group'_tall;
macro shift;
};
end;

*** get the budget shares-we can create them in EXCEL once we have the total
expenditure by non-food groups;

calculate_price fd_cereal fd_fruitvegi fd_meatdairy fd_fatssugars fd_others nfd_alcohol nfd_tobacco nfd_personalitem nfd_cleaning nfd_gasoil;

table distr, by(loc_type) c(mean fd_cereal_pratio mean fd_fruitvegi_pratio mean fd_meatdairy_pratio mean fd_fatssugars_pratio mean fd_others_pratio);
table distr, by(loc_type) c(mean nfd_alcohol_pratio mean nfd_tobacco_pratio mean nfd_personalitem_pratio mean nfd_cleaning_pratio mean nfd_gasoil_pratio);

/*

Notice that we have prices for food items that only account for 34.6% of
the total non-food expenditure;

Next, multiply the budget shares by the price ratio, seperately 
for each region and then sum it over all the food items to get the seperate price
index for all the regions-DONE IN EXCEL TABLE;
*/

	capture program drop calculate_share;
program define calculate_share;	
	  while	  "`1'" != "" {
	  local expitem `1';
	 replace `expitem'_amt = 0 if `expitem'_amt ==.;
	generate share_`expitem' = hhsize_resident * `expitem'_amt / exptot;
	egen all_resident = sum(hhsize_resident);
	egen all_shares = sum(share_`expitem');
   replace share_`expitem' = all_shares / all_resident;
   drop all_resident all_shares;
	macro shift;
		};
end;
calculate_share fd_cereal fd_fruitvegi fd_meatdairy fd_fatssugars fd_others nfd_alcohol nfd_tobacco nfd_personalitem nfd_cleaning nfd_gasoil;
capture program drop rescale_nonfood;
program define rescale_nonfood;
egen nonfood_scaler = rsum(share_nfd_alcohol share_nfd_tobacco share_nfd_personalitem share_nfd_cleaning share_nfd_gasoil);
replace nonfood_scaler = (1 - share_fd_cereal - share_fd_fruitvegi - share_fd_meatdairy - share_fd_fatssugars - share_fd_others) / nonfood_scaler;
while	  "`1'" != "" {
  local nonfood_item `1';
replace share_nfd_`nonfood_item' = share_nfd_`nonfood_item' * nonfood_scaler; 
macro shift;
};
end;
rescale_nonfood alcohol tobacco personalitem cleaning gasoil;	
summarize share_* nonfood_scaler;

/*
calculate_share cer fr_ve me_da fa_su o_fd alch tob per clea gaso tra;

format sh* %4.2f;
*/









/*sum exp* sh* nonfood_scaler;
generate pr_defl = fd_cereal_pratio * share_cer + fd_fruitvegi_pratio * share_fr_ve + fd_meatdairy_pratio * share_me_da + share_fa_su * fd_fatssugars_pratio + fd_others_pratio * share_o_fd;*/

capture program drop price_index;
program define price_index;
generate pr_defl = 0;
while	  "`1'" != "" {
  local item `1';
replace pr_defl = pr_defl + share_`item' * `item'_pratio;
macro shift;
};
end;
price_index fd_cereal fd_fruitvegi fd_meatdairy fd_fatssugars fd_others nfd_alcohol nfd_tobacco nfd_personalitem nfd_cleaning nfd_gasoil;
keep hhnumber loc_typ distr sh* nfd_* fd_* pr_defl;
drop *_qty *_amt;
summarize;
collapse (mean) share_* *_pratio pr_defl, by (loc_type distr);
summarize;
sort loc_type distr;
save K:/BIHS01/Data/STATA/CONSUMPTION/Temp/DistrictPriceIndexTemp.dta, replace;
clear;
use K:/BIHS01/Data/STATA/CONSUMPTION/Dta/Strata.dta;
sort loc_type distr;
merge loc_type distr using K:/BIHS01/Data/STATA/CONSUMPTION/Temp/DistrictPriceIndexTemp.dta;
tab _merge;
keep hhnumber loc_typ distr pr_defl;
tabulate distr loc_type , sum(pr_defl) means;
/*by loc_type distr: sum pr;
summarize;*/
label variable pr_defl "regional weighted price deflators";
label data "regional price deflators";
sort hhnumber;
save K:/BIHS01/Data/STATA/CONSUMPTION/Dta/DistrictPriceIndex.dta, replace;
log close;






