*FoodAggregate.do
*! version July 11, 2001 @ 20:52:01
#delimit;
clear;
	set memory 20m;
	capture log close;
	log using K:/BIHS01/Data/STATA/CONSUMPTION/LOG/FoodAggregate.log,replace;
	set more off;
	use K:/BIHS01/Data/STATA/DATACHECK/DTA/r5_1.dta;

/*
Taking care of household 925  (r,c,h) = (22, 401, 1)
This household does not consume any of the items listed in r5_1.
But this household does consume things like cigarettes and tobacco.
According to Radosveta, the reason is that "The respondent can
not reply / this is the husband/ to this section as he is not the one who does
the shopping in the family. I shall assume that this household
 consume everything but qunatity and price are unknown.
*/
replace q_consu =1 if hhnumber == 925;
replace p_price =. if hhnumber == 925;
replace pricenow =. if hhnumber == 925;
replace c_tot =. if hhnumber == 925;

*REMOVING MEANINGLESS RECORDS;
*summarize if q_consu ==2;
*You get 0 observation for  c_* and p*;
*Essentially those records with q_consu==2 are meaningless;
	drop if q_consu ==2;


*REMOVING RECORDS WITH NO REAL PURCHASE/CONSUMPTION;
*summarize if c_tot==0 & p_pur==0 & p_val ==0;
*There are 47 obesrvations and most of records contains price information;
*pricenow (44 obs) is the only data we may or maynot be able to use.;
*"They know prices of goods which they don't buy";
*Exclusion(Inclusion) of those records should not affect much.;
	drop if c_tot==0 & p_pur==0 & p_val ==0;


*TAKING CARE OF ZERO PRICES (1) pricenow;
*tabulate pricenow;
*We assume that nothing is given free;
*Don't know/Refusal to answer are treated;
*in the same way as no data.;
	replace pricenow =. if pricenow <=0;


*TAKING CARE OF ZERO PRICES (2) p_price;
*tabulate p_price if p_value ==0 & p_purch ==0;
*We find p_price ==0 if p_value ==0 & p_purch ==0;
	replace p_price =. if p_value ==0 & p_purch ==0 & p_price ==0;


	/********************************************************
  ** CHECK CONSISTENCY AMONG PRICES REPORTED AND PRICES ASSUMED;
	Which prices to use to calculate total expenditure? 
	  Form previous analysis it is obvious that most price are exactly
	  the same as reported for actual and for supposed. There are some
	  prices that are different, mostly because some of them are 
	  outliers. In this case I think that we should set a simple rule
	  for deleting outliers and using medians to replace missing 
	  values. The steps are the following:;
	a) Set all prices (actual and assumed) to missing if they are 
	  larger than three times the mean and larger than the mean plus
	  2 times the standard deviation.
	  b) Use the assumed price if available, otherwise 
	  c) Use Actual price if available
	  d) Use the median price by District and rural Urban if available
  *********************************************************/


  ** Calculate price means and standard deviations;
	egen mpricenow = mean(pricenow), by(item);
	egen spricenow = sd(pricenow), by(item);
	egen mp_price=mean(p_price), by(item);
	egen sp_price=sd(p_price), by(item);


	/********************************************************
	  Outliers are defined as larger than 3 times the mean and larger 
	  than the mean + 2 times the standard deviation (Class A outliers)
	  ,or less than the mean minus 2 times the standard deviation
	  (Class B outliers).  In this way only very impossible numbers 
	  are eliminated. 
  *********************************************************/;
   generate outer_a1=1 if pricenow > mpricenow + spricenow * 2 & pricenow !=.;
	generate outer_a2=1 if p_price  > mp_price + sp_price * 2 & p_price !=.;
	generate outer_b1=1 if pricenow > mpricenow * 3 & pricenow !=.;
	generate outer_b2=1 if p_price  > mp_price * 3 & p_price !=.;
	generate lower1=1  if pricenow < mpricenow - spricenow ;
	generate lower2=1  if p_price  < mp_price - sp_price ;

	tabulate item if outer_a2==1 & outer_b2==1 | lower2==1;

	replace pricenow=.   if (outer_a1==1 & outer_b1==1) | lower1==1 ;
	replace p_price=. if (outer_a2==1 & outer_b1==1) | lower2==1 ;

	drop p_tunit p_value p_purch mp_price mpricenow sp_price spricenow outer_a1 outer_a2 outer_b1 outer_b2 lower1 lower2;

	sort hhnumber;

	merge hhnumber using K:/BIHS01/Data/STATA/CONSUMPTION/DTA/Strata.dta;
	tabulate _merge;
	/*There is one household without any consumption at all*/;
list if _merge!=3;
keep if _merge==3;
	drop _merge region clust ethnicity langua_hh intv1_date_dd intv1_date_mm intv2_date_dd intv2_date_mm;

** calculate median pricenows;
	egen mdpri1=median(pricenow), by(item dist loc_ty);
	egen mdpri2=median(pricenow), by(item);

** Calculate pricenow & price index variables - 
	  Price index for each item & Hh is calculated dividing by the 
	  mean
	  ;
	generate prix=pricenow;
	replace prix=p_price if prix==.;
	replace prix=mdpri1 if prix==.;
	replace prix=mdpri2 if prix==.;

	egen mprix=mean(prix), by(item);
	generate pindex=prix/mprix;
	label variable pindex "Price Index";
	drop pricenow p_price mdpri1 mdpri2 mprix;
	summarize item c_tot prix pindex;

	tabulate item, sum(prix);

	/*Counting the number of prices that is more than five
	  times higher than the median price*/
	  count if pindex>5;

**  CHECK CONSISTENCY AMONG QUANTITIES REPORTED 
  **  Total food expenditure is estimated as the quantity consumed 
	  times the price - See price discussion above.;
 
**   First we will chech for the existence of outliers on a per capita 
     quantity basis.  Then we will calculate the value and 
     aggregate over fewer commodity groups. - 
     Price indeces would be welcome he but for the time being....
	  ;
**  We cheched for the possibility of double counting in the case
	  of the production of processed food commodities.  That they would 
	  report the consumption of sugar used for the preparation of 
	  liquor and the consumption of liquor itself.  After carefull
	  checking we concluded that the only serious overreporting could 
	  occur only in the case of milk and milk products.  In fact the 
	  mean of the fresh milk consumption was approximately 3 times as high 
	  if the household reported consumption of own produced white cheese
	  and/or yogurt.  The detailes of the calculation (affecting a total
	  of 234 households consuming more than 10 liters of milk a month)
	  is included in the program EXP11D.DO.
	  ;  
** Report all data on a monthly bases;
	replace c_tot=c_tot*4.2 if c_tunit==1;  /* Report data on Monthly basis */
	replace c_pur=c_pur*4.2 if c_tunit==1;  /* Report data on Monthly basis */
	replace c_rec=c_rec*4.2 if c_tunit==1;  /* Report data on Monthly basis */
	replace c_own=c_own*4.2 if c_tunit==1;  /* Report data on Monthly basis */

** Replace milk quantities with adjusted quantities to take into
	  account the possibility of double coounting ;
	sort hhnumber;
	generate qtmilk   = 0;
	replace  qtmilk   = c_tot if item == 801 & c_tot !=. & c_tot >0;
	by hhnumber: replace  qtmilk = sum(qtmilk);
	generate qtcheese   = 0;
	replace  qtcheese   = c_tot if item == 802 & c_tot !=. & c_tot >0;
	by hhnumber: replace qtcheese = sum(qtcheese);
	generate qtyogur   = 0;
	replace  qtyogur   = c_tot if item == 804 & c_tot !=. & c_tot >0;
	by hhnumber: replace qtyogur  = sum(qtyogur);

	generate qwmilk   = 0;
	replace  qwmilk   = c_own if item == 801 & c_own !=. & c_own >0;
	by hhnumber: replace  qwmilk = sum(qwmilk);
	generate qwcheese   = 0;
	replace  qwcheese   = c_own if item == 802 & c_own !=. & c_own >0;
	by hhnumber: replace qwcheese = sum(qwcheese);
	generate qwyogur   = 0;
	replace  qwyogur   = c_own if item == 804 & c_own !=. & c_own >0;
	by hhnumber: replace qwyogur  = sum(qwyogur);
	
** Check potential difference
  ** Calculate total kgs of milk that had to be used to produce
	  the Yogurt and Cheese produces.  One liter of Milk per Kg of Yougurt
	  and 1.5 liters of milk per kg of cheese
	  ;
	generate owndairy=0;
	by hhnumber:replace owndairy= owndairy[_N] + qwyogur[_N] if qwyogur[_N]>0 & qwyogur[_N] !=.;
	by hhnumber:replace owndairy= owndairy[_N] + qwcheese[_N] * 1.5 if qwcheese[_N] >0 & qwcheese[_N] !=.;

** Calculate total kgs of milk that had to be used to produce
	  the Yogurt and Cheese produces.  One liter of Milk per Kg of Yougurt
	  and 1.5 liters of milk per kg of cheese
	  ;

	by hhnumber: generate cmilk = qtmilk[_N];
	by hhnumber: replace  cmilk = qtmilk[_N]- owndairy[_N] if qtmilk[_N] > 10;
	by hhnumber: replace  cmilk = qtmilk[_N] if cmilk < 1;
** The consumption of milk should be reduced by the amount of milk
	  used for own production, as long as the total quantity of Milk
	  exceeds 10 liters a month and the difference is at least one liter;

	by hhnumber: replace c_tot = cmilk[_N] if item == 801;


** Check and replace outliers;
* Bring in the household size
	  ;
	sort hhnumber;
	merge hhnumber using K:/BIHS01/Data/STATA/CONSUMPTION/DTA/HouseholdSize.dta;

	tabulate _merge;
   drop if _merge !=3;
	drop _merge;
	generate pcqua=c_tot/hhsize_resident;

** Calculate quantities means and standard deviations;

	egen mpcqua=mean(pcqua), by(item);
	egen spcqua=sd(pcqua)  , by(item);

** Outliers are defined as larger than 5 times the mean and larger than
	  the mean + 3 times the standard deviation.  In this way only very 
	  impossible numbers are eliminates (note the conditions are far less
	  restringent now than in the case of prices). 
	  ;
	generate outq1=1 if pcqua>mpcqua+spcqua*3 & pcqua!=.;
	generate outq2=1 if pcqua>mpcqua*5 & pcqua!=.;

	format pcq %5.2f;

	tabulate item, sum(pcq);
	tabulate item if outq1==1 & outq2==1;


** Calculate median values;

	egen mdpcq1=median(pcq), by(item dist loc_ty);
	egen mdpcq2=median(pcq), by(item);

* Calculate the quantity variable and set missing values
	  ;
	generate quant=c_tot if c_tot >=0;
	replace quant=. if outq1==1 & outq2==1;
	replace quant=mdpcq1*hhsize_resident if quant==.;
	replace quant=mdpcq2*hhsize_resident if quant==.;

	sort item;
	merge item using K:/BIHS01/Data/STATA/CONSUMPTION/DTA/Gitemf.dta;

	generate totexp=quant*prix;
tabulate item, sum(totexp);

   generate ownexp = c_own*prix;   /*prix is used instead of pricenow. It is the same most of the time. Evaluation rule must be the same for totexp and ownexp*/
/*blank/refusal to answer/don't know are deemed to be 0*/
replace ownexp = 0 if ownexp ==. | c_own <0;
tabulate item, sum(ownexp);

** Calculate shares of food from own production and/or received 
	  from other sources
	  ;
	generate sharqown=0;
	label variable sharqown "Share Own Production";
	generate sharqrec=0;
	label variable sharqrec "Share Received";
	format shar* %5.2f;

	generate pos_p =c_pur>0 & c_pur!=.;
	generate pos_r =c_rec>0 & c_rec!=.;
	generate pos_o =c_own>0 & c_own!=.;

	summarize pos_*;
	tabulate pos_r pos_o if pos_p==0;
	tabulate pos_r pos_o if pos_p==1;

	replace sharqrec=100 if pos_r==1 & pos_p==0 & pos_o==0;
	replace sharqown=100 if pos_o==1 & pos_p==0 & pos_r==0;

	replace sharqrec=100*c_rec/c_tot if pos_r==1 &
	  (pos_p==1 & (pos_o==0 | pos_o==1)); 
	replace sharqown=100*c_own/c_tot if pos_o==1 &
	  (pos_p==1 & (pos_r==0 | pos_r==1));
            
** After observations shares of missing values have been left at zero
	  There are 60 missing values, mostly food away from home, spieces 
	  and salt
	  ;
	tabulate item, sum(sharqr);
	tabulate item, sum(sharqo);
	tabulate item if sharqr==.;
	replace sharqrec=. if (pos_p==0 & pos_r==0 & pos_o==0) | c_tot==0 ;
	replace sharqown=. if (pos_p==0 & pos_r==0 & pos_o==0) | c_tot==0 ;
	;
	keep hhnum item g_item quant prix pindex totexp distr loc_type sharqrec sharqown ownexp;
	/*Alchohols are not included in food (item# 1204-1207)*/
	  generate a= 0 if item!=.;
	replace a=totexp if (item<1204 | item>1207) & item !=.;
	egen totfood=sum(a), by(hhnumber);
	generate fshare=totexp/totfood if (item<1204 | item>1207) & item!=.;
	drop a;

	gen a=0 if item!=.;
	replace a= totexp if item>=1204 & item<=1207;
	egen totalch=sum(a), by(hhnumber);
	replace fshare=totexp/totalch if item>=1204 & item<=1207 & item !=.;
   drop a;
   save K:/BIHS01/Data/STATA/Consumption/Temp/FoodTemporary.dta,replace;

*****************************************
  ** Collapse to GROUP ITEM AND HH level **
  *****************************************
	  ;
	egen foodexp=sum(totexp), by(hhnum g_item);
	egen ownfdexp=sum(ownexp), by(hhnum g_item);

** Recalibrate shares by category groups
	  ;
** Note by Carlo: If budget shares are rescaled the results are right
	  but the averages are not equal to 1.
	  The best approach would be to replace missing values 
	  with 1 which is the same thing as adding the 
	  percentages of missing commodities.
	  Using the bottom 40% the averages are equal to 1.
	  ;
	egen gfshare=sum(fshare), by(hhnumber g_item);

	egen gshqrec=sum (sharqrec*fshare/gfshare), by(hhnumber g_item);
	egen gshqown=sum (sharqown*fshare/gfshare), by(hhnumber g_item);

	egen  pindhh =sum(pindex*fshare/gfshare), by(hhnumber g_item);

	sort hhnumber g_item;
	by hhnumber g_item: generate a=_n;
	keep if a==1;
	drop a;

	label variable g_item  "Group item";
	label variable foodexp "Food group montly expenditure";
	label variable pindhh  "Price index Hh weight";
	label variable gshqown "Share from Own Production";
	label variable gshqrec "Share from Other Sources";
	label variable gfshare "Food expenditure share";
   label variable ownfdexp "Home Consumption Montholy Expenditure";
summarize ownfdexp, detail;
tabulate g_item, sum(ownfdexp);
	keep hhnumber g_item foodexp gshqown gshqrec gfshare pindhh pindex distr loc_type ownfdexp;

	format foodexp %7.2f;
	format pind* %5.2f;

	label data "Food Exp.";
	save K:/BIHS01/Data/STATA/CONSUMPTION/DTA/FoodAggregate.dta,replace;
	describe;
	summarize;
	log close;
exit, clear;


	
