*Strata.do
*! Version July 19, 2001 @ 11:32:41
#delimit ;
capture log close;
set more off;
clear;
log using K:/BIHS01/Data/STATA/CONSUMPTION/Log/Strata.log, replace;
use K:/BIHS01/Data/STATA/DATACHECK/Dta/r0.dta;


/**************************************************************
Incorporating ethinicity and language. I shall use for now
r11_q1 and r11_q5 for now. The corresponding variable names
in 1995 were pop_grou and lang
**************************************************************/
merge hhnumber using K:/BIHS01/Data/STATA/DATACHECK/DTA/r11.dta;
tab _merge;
drop _merge;

/**************************************************************
Incorporating location type and interveiw dates.
**************************************************************/
sort region clust household;
merge region clust household using K:/BIHS01/Data/STATA/CONSUMPTION/DTA/SampleFrame.dta;
tab _merge;
drop if _merge != 3;
drop _merge;	

/***************************************
Created a new variable that codes: 
   - Bulgarian all Bulgarians 
   - Turks all Turks plus 3 Bulgarian Hhs speaking Turks;
*tabulate ethnicity lan;
**************************************/
generate byte population=.;
replace  population=1 if ethnicity==1 ;
replace  population=2 if ethnicity==2 | (ethnicity==1 & langua_hh==2);
replace  population=3 if ethnicity==3 ;
replace  population=4 if ethnicity>=4 & ethnicity !=.;
label variable population "Population & language Group";
label define population 
      1 "Bulgar."
      2 "Turks"
      3 "Gypsy" 
      4 "Other";
lab values population population;
*tab population;

/***************************************
Create a Sofia other urban and other rural variables
**************************************/
generate byte loc_sec=1 if distr==1;
replace loc_sec=2 if distr>1 & loc_type==1;
replace loc_sec=3 if distr>1 & loc_type==2;
/*There are four clustrs in Sophia city region which are rural*/
list clust if distr==1 & loc_type==2;
replace loc_sec=3 if distr==1 & loc_type==2;

label variable loc_sec "Location Sector";
label define loc_sec
	1 "Sofia"
	2 "O.Urban" 
	3 "O.Rural";
label values loc_sec loc_sec;
tab loc_sec;

/***************************************
Create a Roma oversampling variable
**************************************/
generate byte oversample =0;
replace oversample =1 if hhselec ==4;
label variable oversample "Over-sampling dummy";
label define oversample 0 "Original Sample" 1 "Over-sample";
label values oversample oversample;
tab oversample;

** Clean up add few lables and save the file
label define distr  1 "  Sofia"
              2 "Bourgas"
              3 "  Varna"
              4 " Lovech"
              5 "Montana"
              6 "Plodviv"
              7 "  Russe"
              8 "Sofia R"
              9 "Haskovo";
label values distr distr;
label data "Stratification file";

/***************************************
Create variable for Roma people by GERO.
**************************************/
tab ethnicity int_ethnicity if hhselec!=4, col;

generate byte flag=0;
replace  flag=1 if ethnicity!=int_ethnicity;
label variable flag "Flag for the disagreement between the ethnicity by self-reporting and by other people's views";
label define flag 0 "Agree" 1 "Disagree";
label values flag flag;
  
tab flag;
tab flag if hhselec!=4;

list ethnicity int_ethnicity int_sure int_criterion if flag==1 & hhselec!=4;
list ethnicity int_ethnicity int_sure int_criterion if flag==1 & hhselec==4;

tab inf1_sure;
tab inf2_sure;
tab inf3_sure;

gen inf1=inf1_sure;
replace inf1=0 if inf1_sure==3 |inf1_sure==2;

gen inf2=inf2_sure;
replace inf2=0 if inf2_sure==3 | inf2_sure==2;

gen inf3=inf3_sure;
replace inf3=0 if inf3_sure==3 |inf3_sure==2;

gen sure=(inf1+inf2+inf3);

tab sure;


list inf1_ethnicity inf2_ethnicity inf3_ethnicity sure if flag==1 & hhselec!=4;
list inf1_ethnicity inf2_ethnicity inf3_ethnicity sure if flag==1 & hhselec==4;


*** generate new ethnicity variable based on information on R11;

generate  byte roma=0;
replace   roma=1 if int_ethnicity==3;
***** there are discrepancies in sample - in 2 cases interviewer appear to be wrong;

replace roma=0 if hhnumber==319;	
replace roma=0 if hhnumber==320;

label variable roma "Adjusted Roma Variable based on R11 including other people's opinion";
label define roma 0 "Non-roma" 1 "Roma";
label values roma roma;

tab roma if hhselec!=4;
tab roma if hhselec==4;

generate byte romaself=0;
replace romaself=1 if ethnicity==3;
label variable romaself "Roma Variable based on self-reporting";
label define romaself 0 "Non-roma" 1 "Roma";
label values romaself romaself;


/*Ethnicity adjusted by removing self-reporting bias*'*/	
generate byte ethnicity_adj =ethnicity;
replace  ethnicity_adj=3 if roma != romaself;
replace  ethnicity_adj=4 if ethnicity_adj>3 & ethnicity_adj<12;
label define ethnicity_adj 1 "Bulgarian" 2 "Turk" 3 "Roma/Gypsy" 4 "Other";
label variable ethnicity_adj "Ethnicity (Adjusted)";
label values ethnicity_adj ethnicity_adj;
	
keep  hhnumber distr clust intv1_date_dd intv1_date_mm intv2_date_dd intv2_date_mm ethnicity ethnicity_adj langua_hh population loc_type loc_sec hhselec roma romaself flag oversample;
order hhnumber distr clust intv1_date_dd intv1_date_mm intv2_date_dd intv2_date_mm ethnicity ethnicity_adj langua_hh population loc_type loc_sec hhselec roma romaself flag oversample;
sort hhnumber;
save K:/BIHS01/Data/STATA/CONSUMPTION/Dta/Strata.dta, replace;
log close;
exit,clear;





