*TotalAggregate.do
*! Version July 19, 2001 @ 14:22:49
#delimit ;
	/* exp*_n: nominal aggregation
	   exp*  : aggregation with seasonal adjustment */ 
capture log close;
clear;
	set memory 20m;
	set more off;
	log using K:/BIHS01/Data/STATA/CONSUMPTION/LOG/TotalAggregate.log, replace;
use K:/BIHS01/DAta/STATA/CONSUMPTION/DTA/FoodAggregate.dta;

/********Futhur aggregating food consumption**/
capture program drop doit;
program define doit;
     local varexp ="`1'";
     macro shift;
     local varname ="`1'";
     macro shift;
     generate a=0;
     while "`1'" ~="" {
        replace a=`varexp' if g_item==`1'; 
        macro shift;
     };  
     egen `varname'=sum(a),by (hhnumber);
     drop a;
end;

doit foodexp expcer_n 1     ;
doit foodexp expfr_ve_n 2 3 ;
doit foodexp expme_da_n 4 5 ;
doit foodexp expfa_su_n 6 7 ;
doit foodexp expo_fd_n 8    ;
doit foodexp expalch_n 9    ;

label variable expcer_n   "Exp - Food - Cereal - Nominal";
label variable expfr_ve_n "Exp - Food - Fru & Veg - Nominal";
label variable expme_da_n "Exp - Food - Meat & Dairy - Nominal";
label variable expfa_su_n "Exp - Food - Fats & Sugar - Nominal";
label variable expo_fd_n  "Exp - Food - Other - Nominal";
label variable expalch_n  "Exp - N Food - Alchool - Nominal";

;
sort hhnumber;
quietly by hhnumber: generate a=_n;
keep if a==1;

keep hhnumber expcer_n expfr_ve_n expme_da_n expfa_su_n expo_fd_n expalch_n;
egen expfood_n = rsum(expcer_n expfr_ve_n expme_da_n expfa_su_n expo_fd_n);


/********Futhur aggregating non-food consumption**/
label variable expfood_n "Exp - Food - Total - Nominal";
format exp* %7.2f;
describe;
summarize;
merge hhnumber using K:/BIHS01/Data/STATA/CONSUMPTION/DTA/NonfoodAggregate.dta;
	tab _merge;
list if _merge != 3;
	drop _merge;
rename g_tobacco exptob_n;	
rename g_entertainment expent1_n;
rename g_personalitem expper_n;
rename g_cleaning expclea_n;
rename g_gasoil expgaso_n;
rename g_othtrans exptra_n;
rename g_othnonfood expto_nf_n;
rename g_cloth expclo_n;
rename g_health expheal_n;
egen expfur_a_n = rsum(g_furniture g_applience);
drop g_furniture g_applience;
rename g_entertainment2 expent2_n;
rename g_insurance expins_n;
rename g_saving expsav_n;
rename g_repair exphrep_n;
egen expent_n = rsum(expent1_n expent2_n);
drop expent1_n expent2_n;	
	
label variable exptob_n   "Exp - N Food - Tobacco - Nominal";
label variable expper_n   "Exp - N Food - Personal - Nominal";
label variable expclea_n  "Exp - N Food - Cleaning - Nominal";
label variable expgaso_n  "Exp - N Food - Gasoline - Nominal";
label variable exptra_n   "Exp - N Food - Transport - Nominal";  /*Includes car repairs*/
label variable expto_nf_n "Exp - N Food - Other - Nominal";
label variable expclo_n  "Exp - N Food - Cloths - Nominal";
label variable expheal_n "Exp - N Food - Health - Nominal";
label variable expfur_a_n  "Exp - N Food - Furn. & Appl. - Nominal";
label variable expins_n  "Exp - N Food - Insurance - Nominal";
label variable expsav_n  "Exp - N Food - Savings - Nominal";
label variable exphrep_n "Exp - N Food - House repair - Nominal";
label variable expent_n "Exp - N Food - Entertain - Nominal";
  ** Collpase the observations at the household level
;

capture program drop dotzero;
	program define dotzero;
	while "`1'" != "" {
	  replace `1' =0 if `1' ==.;
	  macro shift;
	  };
end;
dotzero exptob_n expper_n expclea_n expgaso_n exptra_n expto_nf_n expclo_n expheal_n expfur_a_n expins_n expsav_n exphrep_n expent_n;
	
sort hhnumber;
merge hhnumber using K:/BIHS01/Data/STATA/CONSUMPTION/DTA/HouseAggregate.dta;
tab _merge;
drop _merge;
rename exprent exprent_n;
rename expdhea expdhea_n;
rename exphgas exphgas_n;
rename expo_en expo_en_n;
rename expelec expelec_n;
rename expwat expwat_n;
rename exph_fee exph_fee_n;
rename exptel exptel_n;
sort hhnumber;
merge hhnumber using K:/BIHS01/Data/STATA/CONSUMPTION/DTA/EducationAggregate.dta;
tab _merge;
drop _merge;
rename expeduc expeduc_n;
rename expedtr expedtr_n;
generate expnfood_n= expalch_n + exptob_n  + expper_n
            + expclea_n + expgaso_n + exptra_n  + expto_nf_n
	  + expclo_n  + expheal_n + expfur_a_n	  + expins_n  + exphrep_n 
            + expent_n
            + expdhea_n + expelec_n + exphgas_n + expo_en_n + expwat_n  
            + exph_fee_n + exptel_n  
            + expeduc_n + expedtr_n ;
generate exptot_n = expfood_n + expnfood_n;
keep hhnumber exp*;

/**********Making Seasonal Adjustment***/	
** Calculate the deciles to match adjustment factors - use the Pc Variable;
sort hhnumber;
merge hhnumber using K:/BIHS01/Data/STATA/CONSUMPTION/Dta/HouseholdSize.dta;
tabulate _merge;
drop _merge;

generate pcexp_n = exptot_n / hhsize_resident;
label variable pcexp_n "Per Capita - Total Expenditure - Res - Nominal";
format pce %10.2f;
** Calculate deciles of households based on the PC expenditure
   As usual, the ranking is done for Hhs and the variables used
   is the Pc expenditure.;
sort pcexp;
generate hhdecpc=group(10);
generate gdec=0;
replace gdec=1 if hhdecpc<=2;
replace gdec=2 if hhdecpc>2 & hhdecpc<9 ;
replace gdec=3 if hhdecpc>8 & hhdecpc!=.;
tabulate gdec;
label variable hhdecpc "Hh level Pc Exp. Decile";
label variable gdec "Hh Pc Exp. Class bottom 20%/middle 60%/ top 20%";
;
sort hhnumber;
merge hhnumber using K:/BIHS01/Data/STATA/CONSUMPTION/Dta/Strata.dta;
tab _merge;
drop _merge;
rename loc_sec locn;
rename intv1_date_mm monthc;
#replace monthc=monthc - 3;

** Get the seasonal adjustment factor
   The adjustment factor was calculated using the HH Budget 
   survey data of 94.  The same patterns of monthly consumption that 
   were observed for Sofia, O.Urban and Rural Hhs in three 
   expenditure categories - Bottom 20%, Middle 60% and top 20% -
   were applied to the 95 data that was collected over a period of
   only 3 months 
;
sort locn monthc gdec;
merge locn monthc gdec using K:/BIHS01/Data/STATA/CONSUMPTION/Dta/SeasonalAdjustmentFactor.dta;
tab _merge;
drop _merge;

** Adjust the variables that need adjustment
;
generate expcer  =expcer_n  /factor1 ;  /*Exp - Food - Cereal            */
generate expfr_ve=expfr_ve_n   /factor3 ;  /*Exp - Fruits & Vegetables      */
generate expme_da=expme_da_n   /factor2 ;  /*Exp - Food - Meat & Dairy      */
generate expfa_su=expfa_su_n   /factor4 ;  /*Exp - Food - Fats & Sugar      */
generate expo_fd =expo_fd_n  /factor5 ;  /*Exp - Food - Other             */
generate expalch =expalch_n /factor6 ;  /*Exp - N Food - Alchool         */

generate exptob  =exptob_n  /factor25;  /*Exp - N Food - Tobacco         */
generate expper  =expper_n /factor23;  /*Exp - N Food - Personal        */
generate expclea =expclea_n  /factor22;  /*Exp - N Food - Cleaning        */
generate expgaso =expgaso_n /factor14;  /*Exp - N Food - Gasoline        */
generate exptra  =exptra_n  /factor15;  /*Exp - N Food - Transport       */
generate expclo  = expclo_n; /* /factor?;*/
generate expheal  = expheal_n; /* /factor?;*/
generate expent  = expent_n; /* /factor?;*/
*generate expent  =expent_n  /factor ?;  /*Exp - N Food - Entertain       */
*generate exprent =exprent_n /factor ?;  /*Exp - N Food - Rent            */

generate expto_nf=expto_nf_n /factor24;  /*Exp - N Food - Other           */
generate expdhea =expdhea_n /factor8 ;  /*Exp - N Food - Distric Heat    */
generate expelec =expelec_n /factor7 ;  /*Exp - N Food - Electricity     */
generate exphgas =exphgas_n /factor9 ;  /*Exp - N Food - House Gas       */
generate expo_en =expo_en_n /factor9 ;  /*Exp - N Food - O. Energy       */
generate expwat  =expwat_n  /factor11;  /*Exp - N Food - Water           */
generate exph_fee=exph_fee_n /factor10;  /*Exp - N Food - Trash & O. Fees */
generate exptel  =exptel_n  /factor12;  /*Exp - N Food - Telephone       */
generate exphrep = exphrep_n; /* /factor?;*/
generate expfur_a= expfur_a_n; /* /factor?;*/
generate expins = expins_n; /* /factor?;*/
generate expeduc = expeduc_n;
generate expedtr = expedtr_n;
*generate expedtr =expedtr_n /factor ?;  /*                                */

label variable expcer   "Exp - Food - Cereal";
label variable expfr_ve "Exp - Food - Fru & Veg";
label variable expme_da "Exp - Food - Meat & Dairy";
label variable expfa_su "Exp - Food - Fats & Sugar";
label variable expo_fd  "Exp - Food - Other";
label variable expalch  "Exp - N Food - Alchool";
label variable exptob   "Exp - N Food - Tobacco";
label variable expper   "Exp - N Food - Personal";
label variable expclea  "Exp - N Food - Cleaning";
label variable expgaso  "Exp - N Food - Gasoline";
label variable exptra   "Exp - N Food - Transport";  /*Includes car repairs*/
label variable expto_nf "Exp - N Food - Other";
label variable expclo  "Exp - N Food - Cloths ";
label variable expheal "Exp - N Food - Health ";
label variable expfur_a  "Exp - N Food - Furn. & Appl.";
label variable expins  "Exp - N Food - Insurance";
label variable expsav  "Exp - N Food - Savings";
label variable exphrep "Exp - N Food - House repair";
label variable expent "Exp - N Food - Entertain";

;
** RECALCULATE THE TOTAL
;
** Calculate the total Expenditure by Household
;
egen expfood = rsum(expcer expfr_ve expme_da expfa_su expo_fd);
generate expnfood= expalch + exptob  + expper
            + expclea + expgaso + exptra  + expto_nf
            + expclo  + expheal + expfur_a  + expins  + exphrep 
            + expent
            + expdhea + expelec + exphgas + expo_en + expwat  
            + exph_fee+ exptel  
            + expeduc + expedtr ;
generate exptot= expfood + expnfood;
format exp* %7.2f;

label variable expnfood_n "Exp - N Food - Total - Nominal";
label variable exptot_n   "Exp - Total Month Hh - Nominal";
label variable expnfood "Exp - N Food - Total";
label variable exptot   "Exp - Total Month Hh";

label data "HH Mo. Expenditure Nominal";
keep hhnumber exp*;
sort hhnumber;
order hhnumber expcer expfr_ve expme_da expfa_su expo_fd expalch exptob expper expclea expgaso exptra expto_nf expclo expheal expins expsav exphrep expfur_a expent expdhea expelec exphgas expo_en expwat exph_fee exprent exptel expeduc expedtr expfood expnfood exptot expcer_n expfr_ve_n expme_da_n expfa_su_n expo_fd_n expalch_n exptob_n expper_n expclea_n expgaso_n exptra_n expto_nf_n expclo_n expheal_n expins_n expsav_n exphrep_n expfur_a_n expent_n expdhea_n expelec_n exphgas_n expo_en_n exph_fee_n expwat_n exprent_n exptel_n expeduc_n expedtr_n expfood_n expnfood_n exptot_n;
save K:/BIHS01/Data/STATA/CONSUMPTION/Dta/TotalAggregate.dta, replace;
summarize;
describe;
log close;
exit, clear;	



