#delimit ;
capture log close;
	log using ../log/adjustedpercapitaconsumption.log, replace;
clear;
	set more off;
	set memory 20m;
use ../dta/adjustedtotalaggregate.dta;
sum;
keep hhnumber expfood expnfood exptot exptot_d exptot_n;
sort hhnumber;
merge hhnumber using ../dta/strata.dta;
tabulate _merge;
drop _merge;

** For now use the Pc and Ae Variable
;
sort hhnumber;
merge hhnumber using ../dta/householdsize.dta;
tab _merge;
	drop _merge;

label define decile
        1  "decile 1"
        2  "decile 2"
        3  "decile 3"
        4  "decile 4"
        5  "decile 5"
        6  "decile 6"
        7  "decile 7"
        8  "decile 8"
        9  "decile 9"
        10 "decile10"
;

capture program drop pc_ae_variables;
program define pc_ae_variables;
	while "`1'" != "" {
		  local type `1';
if ("`1'" == "0") {local type "";};
generate pcexp`type'  = exptot`type'  / hhsize_resident;
label variable pcexp`type'   "Per Capita - Total Expenditure - Res";
format pcexp`type' %10.2f;

generate aeexp`type'   = exptot`type'  / adulteq;
label variable aeexp`type'   "Adult Equiv - Total Expenditure - Res";
format aeexp`type' %10.2f;

summarize;

** Calculate deciles of households based on the PC expenditure
   As usual, the ranking is done for Hhs and the variables used
   is the Pc expenditure.  All poverty measured involving individuals 
   should be calculated using size weights
;
summarize pcexp`type',detail;    /* Notice the outlier excluded later */
sort oversample pcexp`type';
by oversample: generate hhdecpc`type'=group(10) if oversample ==0;
label variable hhdecpc`type' "Hh level Pc Exp. Decile";
sort oversample aeexp`type';
by oversample: generate hhdecae`type'=group(10) if oversample==0;
label variable hhdecae`type' "Hh level Ae Exp. Decile";
label values hhdecpc`type' decile;
label values hhdecae`type' decile;

/*Createing hhdecpc for oversample*/
replace  hhdecpc`type'=1 if hhdecpc`type' ==.;
sort hhdecpc`type';
forvalues i = 1/10 {;
summarize pcexp`type' if hhdecpc`type' ==`i' & oversample ==0;
scalar min`i' = r(min);
scalar max`i' = r(max);
local  j = `i' -1;
if `j' >= 1 {;
scalar threashold`j' = (max`j' + min`i') / 2;
replace hhdecpc`type' = `i' if pcexp`type' > threashold`j' & oversample==1;
};
}; 
tabulate hhdecpc`type' if oversample ==0;
tabulate hhdecpc`type';

/*Createing hhdecae for oversample*/
replace  hhdecae`type'=1 if hhdecae`type' ==.;
sort hhdecae`type';
forvalues i = 1/10 {;
summarize pcexp`type' if hhdecae`type' ==`i' & oversample ==0;
scalar min`i' = r(min);
scalar max`i' = r(max);
local  j = `i' -1;
if `j' >= 1 {;
scalar threashold`j' = (max`j' + min`i') / 2;
replace hhdecae`type' = `i' if pcexp`type' > threashold`j' & oversample==1;
};
}; 
tabulate hhdecae`type' if oversample ==0;
tabulate hhdecae`type';


** Get few tables on Per capita basis
;
tab hhdecpc`type', sum(hhsize_resident);
tab hhdecpc`type', sum(hhsize_all) ;
tab hhdecpc`type' [w=hhsize_resident], sum(pcexp`type') ;
tab hhdecpc`type' [w=hhsize_resident], sum(aeexp`type') ;
tab hhsize_resident, sum(pcexp`type');

** Get few tables on Adult Equivalent basis
;
tab hhdecae`type', sum(hhsize_resident);
tab hhdecae`type', sum(hhsize_all) ;
tab hhdecae`type' [w=hhsize_resident], sum(aeexp`type') ;
tab hhdecae`type' [w=hhsize_resident], sum(pcexp`type') ;

** Calculate deciles of individuals based on the PC expenditure
   The ranking is done for Hhs adding up the number of people in 
   each household and the variables used is the Pc expenditure.  
   Even in this case poverty measured involving individuals should be 
   calculated using Hhsize as weights
;
sort oversample pcexp`type';
by oversample: gen poppc`type'=sum(hhsize_resident) ;
summarize poppc`type' if oversample==0;
local pmin=_result(5);
local pmax=_result(6);
local pint=int(`pmax'/10);
generate popdecpc`type'=autocode(poppc`type',10,`pmin',`pmax') if oversample ==0;
replace popdecpc`type'=int(popdecpc`type'/`pint');
label variable popdecpc`type' "Pop level Pc Exp. Decile";

/*Createing popdecpc for oversample*/
replace  popdecpc`type'=1 if popdecpc`type' ==.;
sort popdecpc`type';
forvalues i = 1/10 {;
summarize pcexp`type' if popdecpc`type' ==`i' & oversample ==0;
scalar min`i' = r(min);
scalar max`i' = r(max);
local  j = `i' -1;
if `j' >= 1 {;
scalar threashold`j' = (max`j' + min`i') / 2;
replace popdecpc`type' = `i' if pcexp`type' > threashold`j' & oversample==1;
};
}; 
tabulate popdecpc`type' [fw=hhsize_resident] if oversample ==0;
tabulate popdecpc`type' [fw=hhsize_resident];

sort oversample aeexp`type';
by oversample: gen popae`type'=sum(hhsize_resident) ;
summarize popae`type' if oversample==0;
local pmin=_result(5);
local pmax=_result(6);
local pint=int(`pmax'/10);
generate popdecae`type'=autocode(popae`type',10,`pmin',`pmax') if oversample ==0;
replace popdecae`type'=int(popdecae`type'/`pint');
label variable popdecae`type' "Pop level ae Exp. Decile";

/*Createing popdecae for oversample*/
replace  popdecae`type'=1 if popdecae`type' ==.;
sort popdecae`type';
forvalues i = 1/10 {;
summarize aeexp`type' if popdecae`type' ==`i' & oversample ==0;
scalar min`i' = r(min);
scalar max`i' = r(max);
local  j = `i' -1;
if `j' >= 1 {;
scalar threashold`j' = (max`j' + min`i') / 2;
replace popdecae`type' = `i' if aeexp`type' > threashold`j' & oversample==1;
};
}; 
tabulate popdecae`type' [fw=hhsize_resident] if oversample ==0;
tabulate popdecae`type' [fw=hhsize_resident];


/*
sort aeexp`type';
gen popae`type'=sum(hhsize_resident) ;
sum popae`type';
local pmin=_result(5);
local pmax=_result(6);
local pint=int(`pmax'/10);
gen popdecae`type'=autocode(popae`type',10,`pmin',`pmax');
replace popdecae`type'=int(popdecae`type'/`pint');
label var popdecae`type' "Pop level Ae Exp. Decile";

label values popdecpc`type' decile;
label values popdecae`type' decile;
*/

drop poppc`type' popae`type';
macro shift;
};
end;
	
pc_ae_variables "_d" "0" "_n";
** SAVE THE FILE
;
lab data "Per Capita expenditure: deflated";
sort hhnumber;
save ../dta/adjustedpercapitaconsumption.dta, replace;
log close;
exit, clear;



