*HouseholdSize.do
*! Version July 10, 2001 @ 14:27:59
#delimit;
capture log close;
log using ../log/householdsize.log, replace;
clear;
set more off;
use ../../datacheck/dta/r1.dta;

**********************************************
*   COUNTING THE NUMBER OF CHILDREN IN HH    *
**********************************************
*correction of age;
replace age_yrs =0 if age_yrs ==. & age_mth !=.;
*Count the number of children below 15yrs age;
generate child =0;
generate child_resident = 0;
sum;
replace child =1 if 0 <= age_yrs & age_yrs<= 15 & age_yrs !=.;
replace child_resident = 1 if child==1 & hhm ==1;
;
*Count the number of children per household;
egen nchild=sum(child), by(hhnumber); *counts # of child per Hh*;
egen nchild_resident =sum(child_resident), by(hhnumber); *counts # of child per Hh*;
label variable nchild_resident "Number of Children in the household - Resident only";
format nchild_resident %6.2f;
tabulate nchild nchild_resident;
sort hhnumber;


*Count the number of elderly people of 65+yrs of age;
generate elderly =0;
generate elderly_resident = 0;
sum;
replace elderly =1 if 65 <= age_yrs & age_yrs!=.;
replace elderly_resident = 1 if elderly==1 & hhm ==1;
;
*Count the number of children per household;
egen nelderly=sum(elderly), by(hhnumber); *counts # of elderly per Hh*;
egen nelderly_resident =sum(elderly_resident), by(hhnumber); *counts # of elderly per Hh*;
label variable nelderly_resident "Number of Elderly people in the household - Resident only";
format nelderly_resident %6.2f;
tabulate nelderly nelderly_resident;
sort hhnumber;


**********************************************
*   COMPUTING THE SIZE OF HH  (mkhhsize)     *
**********************************************
* Create the hhsize variable-all;
gen temporary=1;
egen hhsize_all=sum(temporary), by(hhnumber);
label variable hhsize_all "HH size - All individuals";
format hhsize_all %6.2f;
;
* Create the hhsize variable-hh member only;
replace temporary=0 if hhm !=1;
egen hhsize_resident =sum(temporary), by(hhnumber);
label variable hhsize_resident "HH size - Resident only";
format hhsize_resident %6.2f;
generate nadult_resident = hhsize_resident - nchild_resident;
label variable nadult_resident "Number of Adults in the household - Resident only";
format nadult_resident %6.2f;

;
** Create the hhsize variable-adult member equivalent;
replace temporary=0;
replace temporary=1 if relationship == 1;
replace temporary=.7 if age_yrs >=14 & age_mth >0 & relationship !=1;
replace temporary=.7 if age_yrs >=14 & age_mth ==0 & relationship !=1;
replace temporary=.5 if age_yrs <14  & age_mth >0;
replace temporary=.5 if age_yrs <14  & age_mth ==0;
replace temporary=.5 if age_yrs ==0  & age_mth >0;
replace temporary=0 if hhm != 1;
egen adulteq=sum(temporary), by(hhnumber);
label variable adulteq "HH Adult equivalent size";
format adulteq %6.2f;

sort hhnumber;	
generate same =0;	  
by hhnumber: replace same =1 if hhnumber[_n+1] == hhnumber[_n];	
tabulate same;
keep if same ==0;
keep hhnumber hhsize_resident hhsize_all adulteq nchild_resident nadult_resident nelderly_resident;	
save ../dta/householdsize.dta, replace;
log close;
exit, clear;
