#delimit ;
capture log close;
log using K:/BIHS01/Data/STATA/INCOME/Log/IndividualInkindBenefitsAggregate.log,replace;

cap prog drop catage;
prog define catage;
   gen catage=0;
   replace catage=1 if age_y>15 & age_y<=24;
   replace catage=2 if age_y>25 & age_y<=34;
   replace catage=3 if age_y>35 & age_y<=54;
   replace catage=4 if age_y>55 & age_y<=70;
end;
*
**  This step calculates income from inkind individual social benefits;
*;
set more off;
clear;
use K:/BIHS01/Data/STATA/DATACHECK/Dta/r1.dta;
keep hhnumber idcode gender age_yrs hhm;
sort hhnumber idcode;
merge hhnumber idcode using K:/BIHS01/Data/STATA/DATACHECK/Dta/r8_7.dta;
tab _merge hhm, miss;
keep if _merge==3;
sum;
drop _merge;

/*checking the consiistency of answer--passed*/
list if oth_inkind ==2 & tot_inkind!=.;
list if i_transp==2 & i_amount !=.;
replace tot_inkind=0 if tot_inkind ==.;
replace i_amount=0 if i_amount ==.;
replace tot_inkind=. if tot_inkind <0;
replace i_amount=. if i_amount <0;

rename i_amount tranben; 
label variable tranben "monthly transp. benefits";

rename tot_inkind othben;
label variable othben "monthly medical benefits";
sum othben tranben;

replace i_stopy =. if i_stopy <0;
replace i_stopm =. if i_stopm <0;
replace i_starty =. if i_starty <0;
replace i_startm =. if i_startm <0;
generate duration1 = i_stopm;
replace  duration1 = duration1 + 12 if i_stopy ==2001;
replace  duration1 = duration1 - i_startm if i_startm > 1999;
replace  duration1 = duration1 - 12 if i_starty ==2001;
replace  duration1 = 12 if duration1 ==. | duration1 > 12;
tab duration1;
list if duration1<0;

**step 1: check for outliers-no child allowance reported;
egen meantran = mean(tranben) if tranben >0;
egen sdtran   = sd(tranben) if tranben >0;
generate flag1=1 if tranben > meantran + sdtran * 5;

egen meanoth = mean(othben) if othben >0;
egen sdoth   = sd(othben) if othben >0;
generate flag2=1 if othben > meanoth + sdoth *5;

** step 2: replace the outliers with missing values;
replace tranben=. if flag1==1;
replace othben=. if flag2==1;

** step 3:calculate the median values;
catage;
egen medtrancg =median(tranben) if tranben >0, by(catage gender);
egen medtran   =median(tranben) if tranben >0;
egen mbencg    =median(othben) if othben > 0, by(catage gender);
egen mben      =median(othben) if othben >0;

** step 4: replace the missing values with median values;
replace tranben=medtrancg if tranben==.;
replace tranben=medtran if tranben==.;
replace othben=mbencg if othben==.;
replace othben=mben if othben==.;

** make it on a monthly basis;
replace tranben=tranben*duration1/12;
replace othben=othben/12;

sum;
keep hhnum idcode othben tranben;
sort hhnum idcode;
sum;
save K:/BIHS01/Data/STATA/INCOME/Dta/IndividualInkindBenefitsAggregate.dta, replace;
log close;
	


