#delimit ;
capture log close;
log using k:\bihs01\data\stata\income\log\MainJobAggregate.log,replace;
*************************************************************;
*                                                           *;
*    Name    : MainJobAggregate.DO               V : 01              *;
*    Date    : July 26,2001                                 *;
*    Infile  : r6_2                                         *;
*    Outfile : MainJobAggregate                                      *;
*                                                           *;
*    OBJECTIVE: Calculates Income from main job employment  *;
*                                                           *;                                                         
*************************************************************;

clear;
set more off;
use k:\bihs01\data\stata\datacheck\dta\r1.dta;
keep hhnumber idcode age_yrs gender hhm;
sort hhnumber idcode;
merge hhnum idcode using k:\bihs01\data\stata\datacheck\dta\r6_2.dta;
tab _merge hhm, miss;

** Check number of children to verify the child allowance
;
gen a= age_y<=18;
egen chil18=sum(a), by(hhnum);
drop a;

keep if _merge==3;
drop _merge;

* Create hours worked per month variables;
replace mj_hrs =. if mj_hrs <0;
tabulate mj_hrs if mj_hrs >70;
gen flagh1=1 if mj_hrs>70 & mj_hrs !=.;

**calculate the number of hours worked;
replace mj_mths =. if mj_mths <0;
tabulate mj_mths if mj_mths >=4;
replace flagh1=2 if mj_mths >=4 & mj_mth !=.;

tab flagh1;
replace mj_hrs=40 if flagh1==1;
replace mj_mths=4 if flagh1==2;
gen hours1=mj_hrs*mj_mths if mj_hrs>0 & mj_mths>0;

**  This program calculates wage income from first job;
sum;
* step 1: check for the outliers by careful observation;

* Create a hours worked per month variables;
* step2: replace outliers i.e.,if a avariable is larger than "mean_vrb+sd_vrb*5" by ".";
;

***PROGRAM STEPS;

cap prog drop outliers;

prog define outliers;

	gen a=`1';
	replace a=. if `1'<0;
	egen mean_`1'= mean(a);
	egen sd_`1'=sd(a);
	replace `1' =. if `1'>mean_`1'+sd_`1'*5;
	drop a;
	end;
		
outliers mj_gros; 
outliers mj_tax;
outliers mj_thome;
outliers mj_deduc;
outliers mj_vacat;
outliers mj_trans;
outliers mj_kinb;
outliers mj_chld;



** step3: calculate the median values-by the type of activity, age group 
          and gender.  Note that for some categiries that do not occur
          very often, it is important to calculate the means only for 
          the occurring cases.  After all the missing values apply only to 
          people that supposely have values;
          ;
gen catage=0;
replace catage=1 if age_y>15 & age_y<=24;
replace catage=2 if age_y>25 & age_y<=34;
replace catage=3 if age_y>35 & age_y<=54;
replace catage=4 if age_y>55 & age_y<=70;



** PROGRAM STEPS: replace negative values with missing values;
cap prog drop domed;
prog define domed; /*To calculate medians when small group is non-zero and non-negative*/

gen a=`1';
replace a=. if `1'<0;
egen m1=median (a), by (`3' `4' `5');
egen m2=median (a);

gen b=m1;
replace b=m2 if b==.;
gen m`2'=b;
replace `1'=m`2' if `1'==.;
drop a b m1 m2;
end;


domed mj_gros  gros mj_activ catage gender;
domed mj_thome take mj_activ catage gender;

egen mratetax=median(mj_tax/mj_gros);

gen rateded=mj_ded/mj_gros;
domed rateded ded mj_activ catage gender;
replace rateded=mded if rateded==.;

domed mj_vaca vacat mj_activ catage gender;
domed mj_tran trans mj_activ catage gender;
domed mj_kinb kind  mj_activ catage gender;

sum m*;

* Child allowance - it is already included in the gross pay - but
  we want to get a seperate variable.  I am not quite sure who is entitled
  to child allowance, now I assume that is families with children under 18
;
gen child1=0;
replace child1=mj_chld if mj_chld>0 & mj_chld~=.;
gen pchil18=child1/chil18;
sum pchil18 if mj_chl!=0;
egen mean_pch = mean(pchil18); 
replace mj_chl=mean_pch*chil18 if mj_chl==.;  /* Approximate value per child*/
replace child1=mj_chld if child1==0 & mj_chld>0 & mj_chld~=.;
drop mean_pch;
** calculate the net income;
*  Note: basically we should get the take home pay as the main measure of 
         payment, if missing we will take the the gross income minus taxes 
         and deductions + child allowance
         Because we assume that take home pay includes the child allowance
         we are going to take the child allowance out to obtain net take 
         home pay
;

replace mj_gros=mgros if mj_gros==.|mj_gros<0;
replace mj_tax=mratetax * mj_gros   if mj_tax==.|mj_tax<0;
replace mj_deduc=rateded * mj_gros if mj_deduc==.|mj_deduc<0;
replace mj_thome=mtake if mj_thome==.|mj_thome<0;
replace mj_vacat=mvacat if mj_vacat==.|mj_vacat<0;
replace mj_trans=mtran  if mj_tran==.|mj_tran<0;
replace mj_kinb=mkind   if mj_kinb==.|mj_kinb<0;

gen wage1=mj_thome;
replace wage1=(mj_gros-mj_tax-mj_ded+mj_ch) if wage1==. | wage1==0 ; 

replace wage1=mtake if wage1==.;
replace wage1=wage1 - child1 if child1*1.1<wage1;


** Estimate the other missing values
;
gen winc1=wage1 + mj_vacat + mj_trans + mj_kinb;

lab var hours1  "Monthly hours worked";
lab var winc1  "Wage income from main job";
lab var child1 "Child allow from main job";

sum m* wage winc1 chi*;

keep hhnum idcode hours winc1 mj_sect mj_empl child1; 
sum;
sort hhnum idcode;
lab data "Wage income 1";
save k:\bihs01\data\stata\income\dta\MainJobAggregate.dta, replace;

log close;



