#delimit ;

capture log close;
log using k:\bihs01\data\stata\income\log\SecondJobAggregate.log,replace;
*************************************************************;
*                                                           *;
*    Name    : SecondJobAggregate.do            V : 01              *;
*    Date    : July 2001                                    *;
*    Infile  : r6_3                                         *;
*    Outfile : SecondJobAggregate                                   *;
*                                                           *;
*    OBJECTIVE: Calculates Income from Second job employment*;
*                                                           *;                                                         *;
*************************************************************;

clear;
set more off;
use k:\bihs01\data\stata\datacheck\dta\r1.dta;
keep hhnumber idcode age_yrs gender hhm;
sort hhnumber idcode;
merge hhnumber idcode using k:\bihs01\data\stata\datacheck\dta\r6_3.dta;
tab _merge hhm, miss;

** Check number of children to verify the child allowance
;
gen a= age_y<=18;
egen chil18=sum(a), by(hhnum);
drop a;

keep if _merge==3;
drop _merge;

**  This program calculates wage income from second job;
sum;
* step 1: check for the outliers by careful observation;

* Create hours worked per month variables;
replace sj_hrs =. if sj_hrs <0;
tabulate sj_hrs if sj_hrs >70;
gen flagh1=1 if sj_hrs>70 & sj_hrs !=.;

**calculate the number of hours worked;
replace sj_mths =. if sj_mths <0;
tabulate sj_mths if sj_mths >=4;
replace flagh1=2 if sj_mths >=4 & sj_mth !=.;

tab flagh1;
replace sj_hrs=40 if flagh1==1;
replace sj_mths=4 if flagh1==2;
gen hours2=sj_hrs*sj_mths if sj_hrs>0 & sj_mths>0;

* step2: replace outliers i.e.,if a avariable is larger than "mean_vrb+sd_vrb*5" by ".";
;

***PROGRAM STEPS;

cap prog drop outliers;

prog define outliers;

	gen a=`1';
	replace a=. if `1'<0;
	egen mean_`1'= mean(a);
	egen sd_`1'=sd(a);
	replace `1' =. if `1'>mean_`1'+sd_`1'*5;
	drop a;
	end;
		
outliers sj_gros;
outliers sj_tax;
outliers sj_thome;
outliers sj_deduc;
outliers sj_vacat;
outliers sj_trans;
outliers sj_kinb;
outliers sj_chld; 

** step3: calculate the median values-by the type of activity, age group 
          and gender.  Note that for some categiries that do not occur
          very often, it is important to calculate the means only for 
          the occurring cases.  After all the missing values apply only to 
          people that supposely have values;
          ;
gen catage=0;
replace catage=1 if age_y>15 & age_y<=24;
replace catage=2 if age_y>25 & age_y<=34;
replace catage=3 if age_y>35 & age_y<=54;
replace catage=4 if age_y>55 & age_y<=70;

** PROGRAM STEPS: replace negative values with missing values;
cap prog drop domed;
prog define domed; /*To calculate medians when small group is non-zero and non-negative*/

gen a=`1';
replace a=. if `1'<0;
egen m1=median (a), by (`3' `4' `5');
egen m2=median (a);

gen b=m1;
replace b=m2 if b==.;
gen m`2'=b;
replace `1'=m`2' if `1'==.;
drop a b m1 m2;
end;


domed sj_gros  gros sj_activ catage gender;
domed sj_thome take sj_activ catage gender;

egen mratetax=median(sj_tax/sj_gros);

gen rateded=sj_ded/sj_gros;
domed rateded ded sj_activ catage gender;
replace rateded=mded if rateded==.;

domed sj_vaca vacat sj_activ catage gender;
domed sj_tran trans sj_activ catage gender;
domed sj_kinb kinb  sj_activ catage gender;

sum m*;

* Child allowance - it is already included in the gross pay - but
  we want to get a seperate variable.  I am not quite sure who is entitled
  to child allowance, now I assume that is families with children under 18
;
gen child2=0;
replace child2=sj_chld if sj_chld>0 & sj_chld~=.;
gen pchil18=child2/chil18;
sum pchil18 if sj_chl~=0;
egen mean_pch = mean(pchil18);
replace sj_chl=mean_pch*chil18 if sj_chl==.;  /* Approximate value per child*/
replace child2=sj_chld if child2==0 & sj_chld>0 & sj_chld~=.;
drop mean_pch;
** calculate the net income;
*  Note: basically we should get the take home pay as the main measure of 
         payment, if missing we will take the the gross income minus taxes 
         and deductions + child allowance
         Because we assume that take home pay includes the child allowance
         we are going to take the child allowance out to obtain net take 
         home pay
;

** Estimate the other missing values
;
replace sj_gros=mgros if sj_gros==.|sj_gros<0;
replace sj_tax=mratetax * sj_gros   if sj_tax==.|sj_gros<0;
replace sj_deduc=rateded * sj_gros if sj_deduc==.|sj_gros<0;

replace sj_vacat=mvacat if sj_vacat==.|sj_vacat<0;
replace sj_trans=mtran  if sj_tran==.|sj_tran<0;
replace sj_kinb=mkinb   if sj_kinb==.|sj_kinb<0;

*****;

gen wage2=sj_thome;
replace wage2=(sj_gros-sj_tax-sj_ded+sj_ch) if wage2==.|wage2<0;
replace wage2=mtake if wage2==.;
replace wage2=wage2 - child2 if child2*1.1<wage2 ;

gen winc2=wage2; /* NO BENEFITS HERE MISSING WOULD MESS IT UP */

lab var hours2  "Monthly hours worked Sec Job";
lab var winc2  "Wage income from sec job";
lab var child2 "Child allow from sec job";

sum sj_* wage winc2 chi*;

keep hhnum idcode hours winc2 child2; 
sum;
sort hhnum idcode;
lab data "Wage income 2";
save k:\bihs01\data\stata\income\dta\SecondJobAggregate, replace;

log close;
