#delimit ;
capture log close;
log using K:/BIHS01/Data/STATA/INCOME/Log/UnemploymentBenefitsAggregate.log,replace;

*
**  This step calculates income from Unemployment benefits;
*;
set more off;
clear;
use K:/BIHS01/Data/STATA/DATACHECK/Dta/r1.dta;
keep hhnumber idcode gender age_yrs hhm;
sort hhnumber idcode;
merge hhnumber idcode using K:/BIHS01/Data/STATA/DATACHECK/Dta/r8_5.dta;
tab _merge hhm, miss;
keep if _merge==3;
sum;
drop _merge;
capture program drop mth_yr_adjust;
	program define mth_yr_adjust;
   local 
	replace year  = . if year < 0;
/*in case we have two digit numbers, we convert it to four digit numbers*/
	replace year  = year + 2000 if year < 02 & year != .;
	replace year  = year + 1900 if year > 01 & year < 100 & year != .;
	replace year  = . if year <1900 | year > 2001;
	replace year  = 1997 if year < 1997 & year != .;
	replace year  = 2001 if year == .;
   replace month = . if month < 1;
	replace month = . if month > 12;
   replace month = . if month > 5 & year == 2001;
	replace month = . if year < 2000; /*Don't care the month if before 2000*/
	end;

** Note: the unemployment benefits are given for the period of
   unemployment. If we take as a monthly value the last payment
   we might be adding the salary to the benefit and inflate the 
   income of that person.;
rename un_lsty year;
rename un_lstm month;
mth_yr_adjust;
rename year un_lsty;
rename month un_lstm;
	
** First we are goint to limit the calculation of income to people that
   received benefits during the last 12 Months.
   Then we are goint to miultiply them by the number of months they 
   have received it and divide it by 12 - Monthly amount  calculated 
   on a annualized basis -
;
gen flagu=1 if (un_lstm>=5 & un_lsty==2000) | (un_lsty==2001);
keep if flagu==1;

rename un_amnt unemben;
label variable unemben "monthly unemp. benefits";
rename un_subsi child5;
label variable child5 "monthly child subsidy";

**step 1: check for outliers-child allowance reported;
replace unemben =0 if unemben ==.;
replace unemben =. if unemben <0;
egen mean = mean(unemben) if unemben >0;
egen sd   = sd(unemben) if unemben >0;
gen flag1=1 if unemben > mean + sd * 5 & unemben!=.; 
drop mean sd;
replace child5 =0 if child5 ==.;
replace child5 =. if child5 <0;
egen mean = mean(child5) if child5 >0;
egen sd   = sd(child5) if child5 >0;
gen flag2=1 if child5 > mean + sd * 5 & child5!=.; 
drop mean sd;
	
** step 2: replace the outliers with missing values;
replace unemben=. if flag1==1;
replace child5  =. if flag2==1;

** Step 3: Generate the medians;
egen medben=median(unemb) if unemb >0;
egen medchi=median(child5) if child5 >0;

** step 4: replace the missing values with median values;
replace unemben=medben if unemben==.;
replace child5=medchi  if child5==.;

rename un_lsty year;
rename un_lstm month;
sort year month;
merge year month using K:/BIHS01/Data/STATA/INCOME/Dta/Deflator.dta;
tab _merge;
drop if _merge !=3;
replace unemb =unemb *padj;
replace child5=child5*padj;

** Calculate the monthly variable
;
replace un_long=. if un_long <0;
replace un_long=6 if un_long==.;
replace un_long=12 if un_long>12;

replace unemben=unem*un_long; /*annual figure*/
replace unemben=unemb/12;/*monthly average including those month without unemployment benefits payment*/

summarize;

keep hhnumber idcode unemben child5;
sort hhnumber idcode;
save K:/BIHS01/Data/STATA/INCOME/Dta/UnemploymentBenefitsAggregate.dta, replace;
log close;
	




