#delimit ;
capture log close;
	log using ../log/agriculturalinputsaggregate.log, replace;
*************************************************************;
*                                                           *;
*    Name    : CLCINCD.DO               V : 01              *;
*    Date    : NOV 28, 1995                                 *;
*    Infile  : FILE26V0, FILE31V0                           *;
*    Outfile : AGINC4                                       *;
*                                                           *;
*    OBJECTIVE: Calculate Agricultural costs & Incomes      *;
*                (inputs+labor+other costs)                 *;
*                                                           *;
*************************************************************;
set more off;
clear;
set maxobs 10000;

*** Calculates the cost of Ag. inputs ***********

*   The general methodology will be to: 
      a)  Limit the analysis to the Hhs that reported
	  known quantities of inputs
      b)  Calculate the price of the inputs 
      c)  Calculate the amount for those commodities without values
	  using the median unit price
      d)  Adjust the values for inflation using the CPI - in case the 
	  year is not reported or the month in not reported use Jan 95
;
use ../../datacheck/dta/r6_6_2.dta, clear;
*drop if crop != 0; /*interested in total quantity/amount only*/;
/*for here, I shall assume that don't know and refusal to answer
are equal to zero. Nothing was done in 1995*/
generate flag = (crop ==0);
replace f_chem_amnt =0 if f_chem_amnt < 0 & flag !=1;
replace f_org_amnt  =0 if f_org_amnt  < 0 & flag !=1;
replace p_amnt =0      if p_amnt      < 0 & flag !=1;
replace s_amnt =0      if s_amnt      < 0 & flag !=1;
replace sdl_amnt =0    if sdl_amnt    < 0 & flag !=1;
replace o_amnt =0      if o_amnt      < 0 & flag !=1;
replace f_chem_amnt =. if f_chem_amnt < 0 & flag ==1;
replace f_org_amnt  =. if f_org_amnt  < 0 & flag ==1;
replace p_amnt =.      if p_amnt      < 0 & flag ==1;
replace s_amnt =.      if s_amnt      < 0 & flag ==1;
replace sdl_amnt =.    if sdl_amnt    < 0 & flag ==1;
replace o_amnt =.      if o_amnt      < 0 & flag ==1;
sort flag;
by flag:sum;
sort hhnumber flag;
collapse (sum) f_chem_amnt f_org_amnt p_amnt s_amnt sdl_amnt o_amnt, by (hhnumber flag);
generate aginput0 = f_chem_amnt + f_org_amnt + p_amnt + s_amnt + sdl_amnt + o_amnt if flag == 1;
generate aginput1 = f_chem_amnt + f_org_amnt + p_amnt + s_amnt + sdl_amnt + o_amnt if flag != 1;
egen aginput2 = rsum(f_chem_amnt f_org_amnt p_amnt s_amnt sdl_amnt o_amnt) if flag == 1;
sort hhnumber;
collapse (mean) aginput0 aginput1 aginput2, by(hhnumber);
sum;
generate aginput = aginput0; /*in fact, this line is enough, but I just leave other lines in case of future use*/
replace  aginput = aginput1 if aginput ==.;
sort hhnumber;

list if ((aginput-aginput2)/aginput >0.03 | (aginput-aginput2)/aginput <-0.03) & aginput != 0;
replace aginput = aginput / 12;
tab aginput;
label var aginput "Agricultural Cost: Crop Inputs";
keep hhnumber aginput;
save ../dta/agriculturalinputsaggregate.dta, replace;
sum;
log close;









