*CropAggregate.do
*! VersionJuly 16, 2001 @ 14:53:42
#delimit ;
capture log close;
log using ../log/cropaggregate.log, replace;
set more off;

******************* PART I: AGRICULTURE INCOME **************************;
* Agricultural Income is calculated as sum of Agricultural revenue
  and Consumption from agricultural production
;
clear;
use ../../datacheck/dta/r6_6_1.dta;
sort hhnumber;
merge hhnumber using ../../consumption/dta/strata.dta;
tabulate _merge;
keep if _merge==3;
drop _merge; /*_merge ==2 using from data only (i.e. no crop production for those households */

tabulate crop;
summarize;
tabulate crop if kg_harv ==.;

/** There are 22 entries for which we do not have values
	  for unit price and the quantity harvested. For those
	  entries, the quantity sold is either unobserved (1 obs)
	  or zero (21 obs). We assume that the income from
	  those entries is zero and drop those observations.*/
drop if kg_harv==.;

*** Step 0: Take care of zero values for current prices;

** Note that we have current prices on 288 observations and unit price on 300
observations, for those who reported selling their harvest. So to get the 
total revenue we are going to use the current crop prices. 
For those cases where the prices are not reported we are going to use
median prices by commodity and area
;

generate flagp1=0;
replace flagp1=1 if avrg_pri==0 & kg_sold>0 & kg_sold!=.;
replace flagp1=2 if avrg_pri==. & kg_sold>0 & kg_sold!=.;
replace flagp1=3 if (avrg_pri==0 | avrg_pri==.) & kg_sold==0;
replace flagp1=4 if avrg_pri <0 & avrg_pri !=.;
tabulate flagp1;

** Price should not be equal to zero if the qty sold is greater than zero, 
so we will consider those prices to be missing;
replace avrg_pri=. if flagp1==1 | flagp1==2;
replace avrg_pri=. if avrg_pri <0; /*don't know & refusal to answer */

** Unkown quantity is replaced by no observation;
replace kg_harv =. if kg_harv <0;
replace kg_sold =. if kg_sold <0;
replace kg_consu =. if kg_consu <0;
replace kg_barte =. if kg_barte <0;
replace kg_input =. if kg_input <0;
	
**STEP 2: Calculate the mean and STD of price and qty. by crops;
egen mqty=mean(kg_harv), by(crop);
egen sqty=sd(kg_harv), by(crop);
egen nqty=count(kg_harv), by(crop);
egen sales_qty=mean(kg_sold), by(crop);
egen mprice=mean(avrg_pri), by(crop);
egen sprice=sd(avrg_pri), by(crop);
egen nprice=count(avrg_pri), by(crop);

drop if (mqty ==.) & (mprice ==.);

/*
save agstep01,replace;
sort crop;
quietly by crop: gen a=_n ;
keep if a==1;
format mqty sqty %7.2f;
format mpri spri %5.2f;
format nqty npri %5.0f;
list crop mqty sqty nqty mpri spri npri, noobs nodisplay;
clear;
use agstep01;
*/
	  
**STEP 3: Check for outliers-both qty and price by distr and locality;

** For prices;
generate flag1=1 if avrg_pri>mprice+sprice*2 & avrg_pri!=.;
generate flag2=1 if avrg_pri>mprice*5 & avrg_pri!=.;

tabulate flag1 flag2;
tabulate crop flag1;
tabulate crop flag2;

replace avrg_pri=. if flag1==1 | flag2==1;

egen medianp =median(avrg_pri), by(crop loc_typ);
egen nmedianp=median(avrg_pri), by(crop);
egen nmedianup=median(unit_pri), by(crop);
egen z = median(avrg_pri);

label variable medianp "median crop price";

display z;	
/*There are some crops for which average price is not available.
Please loot at ~/Documents/Mail/Boryana and
 ~/Data/Original/etc/Cropprices.xls for the source of numbers
I take the average of May and April when both prices are available.
If not, I took the figures from 1995 do-file (for Beetroot and Pears).
I adjusted the figure by the cpi for
March 2001 (3677.1 with 1995 base =100) taken from IFS (Blue Book).
Also, note that there has been a denomination. Thus the factor of
3677.1/100/100 = 0.36771 is applied.
*/

/*Rye*/
replace nmedianp=0.96 if crop==2 & nmedianp ==.  ;

/*Forage Plants
As there is no one uniform price for forage and they have given the following alternatives:
straw - 121,12 leva per ton average for Jan - March
hay - 269,23 leva per ton average for Jan. - March
peas for forage - 382,02 leva per ton average for Jan. - March
rye - 208,33 leva per ton average for Jan. - March
I shall take the arithmetic average of those.
*/
replace nmedianp= (0.12112 + 0.26923 + 0.38202 + 0.20833)/4 if crop==7 & nmedianp ==.  ;

/*Sugar beet*/
replace nmedianp= (1.06 + 1.03) if crop==8 & nmedianp ==.  ;

/*Beetroot from 1995 do file adjusted to 2001*/
replace nmedianp= 10 * 0.36771  if crop==9 & nmedianp ==.  ;

/*Other leguminous plants (peas lentils, soy)
I take the average of peas and lentils*/
replace nmedianp= (1.28 + 1.27 + 1.83 + 1.79) / 4 if crop==11 & nmedianp ==.  ;

/*Peanuts; whole market price adjusted to 2001*/
replace nmedianp= 2.50 * 3679.1 / 3449.3 if crop==15 & nmedianp ==.  ;

/*Marrows*/
replace nmedianp= (1.28 + 1.06) / 2 if crop==22  & nmedianp ==.  ;

/*Leafy vegetables */
replace nmedianp= (0.58 + 0.59) / 2 if crop==24 & nmedianp ==.  ;

/*Melons*/
replace nmedianp= (0.71 + 0.86) /2  if crop==26 & nmedianp ==.  ;

/*Pumpkin, squash; whole market price adjusted to 2001*/
replace nmedianp= 0.380 * 3679.1 / 3449.3  if crop==27 & nmedianp ==.  ;

/*Apples*/
replace nmedianp=(1.2 + 1.33)/2 if crop==28 & nmedianp ==.  ;

/*Pears; from 1995 do file adjusted to 2001*/
replace nmedianp= 100 * 0.36771 if crop==29  & nmedianp ==.  ;

/*Cherries/Morrelli
I just use the price for cherries*/	  
replace nmedianp=1.81 if crop==30 & nmedianp ==.  ;

/*Strawberries/Rasberries
I just use the price for strawberries*/	  
replace nmedianp=2.74 if crop==34  & nmedianp ==.  ;
;

replace nmedianp = z if nmedianp ==.;
generate price=avrg_pri;
replace price=medianp if price==.;
replace price=nmedianp if price==.;


** Check for outliers for output consumed, used for seed, salaries, barter;
** This is done by careful observation, item by item;
** Note that quantities consumed should be estimated using the 
   residual from harvest from sales and other allocations.
   The values that are still missing should be replaced using
   the ratio consumption to land available. But the results are 
   very unrealible we better stick with median consumption.
   Amount sold is treated in the same way.
	  ;
gen flag3=1 if kg_harv>mqty+sqty*2 & kg_harv!=.;
gen flag4=1 if kg_harv>mqty*5 & kg_harv!=.;
tabulate flag3 flag4;
tabulate crop flag3;
tabulate crop flag4;
tabulate crop if flag3==1 & flag4==1;
replace kg_harv=. if flag3==1 & flag4==1;

gen flag5=1 if kg_sold>mqty+sqty*2 & kg_sold!=.;
gen flag6=1 if kg_sold>mqty*5 & kg_sold!=.;
tabulate flag5 flag6;
tabulate crop flag5;
tabulate crop flag6;
tabulate crop if flag5==1 & flag6==1;
replace kg_sold=. if flag5==1 & flag6==1;
;
summarize crop kg_harv kg_sold kg_input kg_consu kg_given kg_barte price;
	/* Arbitaray upper bounds were used in 1995. I set the upper bound
	  as mean + standard deviation * 5. It must be modified even when
	  this type of replacement is used at all.*/
*set trace off;
capture program drop remove_outlier;
program define remove_outlier;
local item `1'; 
egen mean = mean(`item');
egen sd   = sd(`item');
replace `item' =. if `item' > mean + sd * 5;
drop mean sd;
end;
remove_outlier kg_harv;
remove_outlier kg_consu;
remove_outlier kg_input;
remove_outlier kg_given;
remove_outlier kg_barte;


replace kg_consu=. if kg_consu>kg_harv & kg_consu!=.;
replace kg_input=. if kg_input>kg_harv & kg_input!=.;
replace kg_given=. if kg_given>kg_harv & kg_given!=.;
replace kg_barte=. if kg_barte>kg_harv & kg_barte!=.;

** Step 6: Compute value of Agriculture sales - 
   we use the reported amount of sales
; 
generate sales_ratio = sales_qty / mqty;
replace kg_sold=kg_harv * sales_ratio if kg_harv!=. & kg_sold==.;
replace kg_sold=sales_qty if kg_sold ==.;

gen revenue = kg_sold * price;

** Step 7: Compute value of Agriculture Home consumption
;
gen cons=(kg_harv-kg_sold-kg_input-kg_given);
replace cons=(kg_harv-kg_sold) if cons==.;
/*
	replace cons=. if cons<5;
*/
replace kg_cons=cons if kg_cons==.;

sum crop kg* rev cons;

*** There are still few values of consumption (11) that are not
    evaluated. Straight median will be used
;
egen medcon  = median(kg_con), by (crop loc_typ);

** Replace the missing with median values;
tabulate crop if kg_cons==. , sum(medcon);
replace kg_consu=medcon if kg_consu==.;
summarize crop kg*;

generate homecon= kg_consu * price;

summarize crop kg_harv avrg_pri medianp price rev home cons;

tab crop if kg_sold>0, sum(kg_sold);
tab crop if kg_sold>0, sum(rev);

tab crop if kg_con>0, sum(kg_consu);
tab crop if kg_con>0, sum(homecon)
;
keep hhnum crop rev homecon;
replace revenue = revenue / 12;
replace homecon =homecon / 12;
sort hhnumber;
merge hhnumber using ../../consumption/dta/strata.dta;

collapse (sum) revenue homecon, by (hhnumber);
rename rev agcrop;
rename homecon agcon1;
summarize;
sort hhnumber;
label variable agcrop  "Agriculture : Sales Crop";
label variable agcon1 "Agriculture : Consumption Crop";

label data "Ag income from crop";
save ../dta/cropaggregate.dta, replace;

*erase agstep01.dta;
log close;
