#delimit ;
capture log close;
log using ../log/householdbenefitsaggregate.log,replace;

********* HOUSEHOLD LEVEL BENEFITS ********;

*
**  This step calculates income from cash & kind HH social benefits;
*;
set more off;
clear;
set memory 20m;
use ../../datacheck/dta/r8_9.dta;
merge hhnumber using ../../consumption/dta/strata.dta;
tab _merge;
drop _merge;
keep if b_wherh==1;
tabulate bcode b_wherh;
sum;
tab b_stopy;
replace b_stopy =. if b_stopy ==99 | b_stopy <0; /*no negative number, though*/
drop if b_stopy < 2000;
summarize;

** Make the total benefits on a monthly basis;

rename b_amount hhben;
label variable hhben "monthly hh. social benefits";

replace hhben = 0 if hhben ==.;
replace hhben = . if hhben <0;	

**step 1: check for outliers-no child allowance reported;
egen mean = mean(hhben) if hhben >0, by (bcode);
egen sd   = sd(hhben)   if hhben >0, by (bcode);
gen flag1=1 if hhben > mean + sd * 10;

** step 2: replace the outliers with missing values;
replace hhben=. if flag1==1;

** step 3:calculate the median values-by type of benefit;
egen medben=median(hhben) if hhben >0, by(bcode);

** step 4: replace the missing values with median values;
replace hhben=medben if hhben==.;

*** make it on a monthly basis;
replace hhben=(hhben/12);

sum hhnum bcode hhben;
tab bcode, sum(hhben);

sort hhnumber;	
merge hhnumber using ../../consumption/dta/strata.dta;
tab _merge;
collapse (sum) hhben, by(hhnumber);
rename hhben sb_hhold;
sort hhnumber;
label variable sb_hhold "Social Benefit: Household";
save ../dta/householdbenefitsaggregate.dta, replace;
summarize;
log close;
	


