*LiveStockAggreate.do
*! VersionJuly 17, 2001 @ 13:21:05
#delimit ;
capture log close;
log using ../log/livestockaggregate.log, replace;
set more off;
clear;
***************  PART II: LIVESTOCK INCOME -FROM HERDS GROWTH ***************;

*  There are in general two approaches to calculate income from livestock:
   the first is to use the net growth in the heard and the second is to 
   use the net of purchases, sales and consumption. The first method
   is too difficult to apply without detailed information of the herds,
   so we will use the second. 
   This method does not take into account the change in heard population
   nor the change in assets.
;
use ../../datacheck/dta/r6_8.dta;
sort hhnumber;
summarize;
merge hhnumber using ../../consumption/dta/strata.dta;
tab _merge;
keep if _merge==3;
	drop _merge;
*	set trace on;

** Step 1: adjust for inflation during the month and year of sale;
** In some cases we see that the price is reported but the time of selling
   is not - we only use the prices when we have the time of selling
   otherwise we use the median sale price
;

** Bring in the priceadj file;
	capture program drop mth_yr_adjust;
	program define mth_yr_adjust;
	replace year  = . if year < 0;
/*in case we have two digit numbers, we convert it to four digit numbers*/
	replace year  = year + 2000 if year < 02 & year != .;
	replace year  = year + 1900 if year > 01 & year < 100 & year != .;
	replace year  = . if year <1900 | year > 2001;
	replace year  = 1997 if year < 1997 & year != .;
	replace year  = 2001 if year == .;
   replace month = . if month < 1;
	replace month = . if month > 12;
   replace month = . if month > 5 & year == 2001;
	replace month = . if year < 2000; /*Don't care the month if before 2000*/
	end;
	
	capture program drop aggregate_livestock;
	program define aggregate_livestock;
   generate agliv = 0;
	generate agcon2 = 0;
   while "`1'" != ""{
	local livestock `1';
	tab rece_mth_`livestock' rece_yr_`livestock';
   rename rece_yr_`livestock' year;
	rename rece_mth_`livestock' month;
   mth_yr_adjust;
	sort year month;
	merge year month using ../dta/deflator.dta;
tab _merge;
drop if _merge==2;
   gen price_s_`livestock' = price_rc_`livestock' * padj;
   drop _merge month year cpi padj price_rc_`livestock';
	tab paid_mth_`livestock' paid_yr_`livestock';
   rename paid_yr_`livestock' year;
   rename paid_mth_`livestock' month;
   mth_yr_adjust;
	sort year month;
	merge year month using ../dta/deflator.dta;
tab _merge;
drop if _merge==2;
   gen price_p_`livestock' = price_pd_`livestock' * padj;
   drop _merge month year cpi padj price_pd_`livestock';	
** Step 2: get the mean and std dev. by animals;
tab price_s_`livestock';
tab price_p_`livestock';
replace price_s_`livestock' = 0 if price_s_`livestock' ==.;
replace price_p_`livestock' = 0 if price_p_`livestock' ==.;
replace price_s_`livestock' = . if price_s_`livestock' <0;
replace price_p_`livestock' = . if price_p_`livestock' <0;
/* Only one price available for chicken - too high */
*replace price_p_`livestock'= 150 if anim==5; 

egen mprice_s=mean(price_s_`livestock') if price_s_`livestock' >0;
egen sprice_s=sd(price_s_`livestock') if  price_s_`livestock' >0;
egen mprice_p=mean(price_p_`livestock') if  price_p_`livestock' >0;
egen sprice_p=sd(price_p_`livestock') if  price_p_`livestock' >0;

** Step 3: check for outliers
           There are not too many prices to begin with
           we will rely on the few that are available
           and we will set a few by hand
;
gen flag1=1 if price_s_`livestock'> mprice_s+2*sprice_s & price_s_`livestock'!=.;
gen flag2=1 if price_s_`livestock'> 5*mprice_s & price_s_`livestock'!=.;
gen flag3=1 if price_p_`livestock'> mprice_p+2*sprice_p & price_p_`livestock'!=.;
gen flag4=1 if price_p_`livestock'> 4*mprice_p & price_p_`livestock'!=.;
drop mprice_s sprice_s mprice_p sprice_p;
	
tab flag1 flag2, miss;
tab flag1 ;
tab flag2 ;

tab flag3 flag4, miss;
tab flag3 ;
tab flag4 ;

** step 4: replace the outliers with missing;

replace price_s_`livestock'=. if flag1==1 & flag1==1;
replace price_p_`livestock'=. if flag3==1 & flag4==1;
drop flag1 flag2 flag3 flag4;
	
** Calculate the Median price and replace missings;

egen medp_s = median(price_s_`livestock') if price_s_`livestock' > 0, by(loc_typ) ;
egen nmedp_s= median(price_s_`livestock') if price_s_`livestock' > 0;
egen medp_p = median(price_p_`livestock') if price_p_`livestock' > 0, by(loc_typ);
egen nmedp_p= median(price_p_`livestock') if price_p_`livestock' > 0;

summarize medp_s medp_p;

replace price_s_`livestock'=medp_s  if price_s_`livestock'==.;
replace price_s_`livestock'=nmedp_s if price_s_`livestock'==.;
replace price_s_`livestock'=0 if price_s_`livestock'==.;
replace price_p_`livestock'=medp_p  if price_p_`livestock'==.;
replace price_p_`livestock'=nmedp_p if price_p_`livestock'==.;
replace price_p_`livestock'=0 if price_s_`livestock'==.;
drop medp_s nmedp_s medp_p nmedp_p;
	
sum price*;

*** Check for outliers in herd population-and replace them as missing;

sum n_purch_`livestock' n_consum_`livestock' n_sold_`livestock';
sum(n_purch_`livestock') if n_purch_`livestock'>0;
sum(n_consum_`livestock') if n_consum_`livestock'>0;
sum(n_sold_`livestock') if n_sold_`livestock'>0;

replace n_purch_`livestock'=0 if n_purch_`livestock' ==.;
replace n_consum_`livestock'=0 if n_consum_`livestock' ==.;
replace n_sold_`livestock'=0 if n_sold_`livestock' ==.;

replace n_purch_`livestock'=. if n_purch_`livestock' <0;
replace n_consum_`livestock'=. if n_consum_`livestock' <0;
replace n_sold_`livestock'=. if n_sold_`livestock' <0;
/*
replace n_purch_`livestock'=. if n_purch_`livestock'>20;
replace n_consum_`livestock'=. if n_consum_`livestock'>20;
replace n_sold_`livestock'=. if n_sold_`livestock'>5;
*/
** Calculate the median values;

egen medpur=median(n_purch_`livestock'), by (loc_typ);
egen medcons=median(n_consum_`livestock'), by (loc_typ);
egen medsold=median(n_sold_`livestock'), by (loc_typ);

** Replace the missing with median values;

replace n_purch_`livestock'=medpur  if n_purch_`livestock'==.;
replace n_consum_`livestock'=medcons if n_consum_`livestock'==.;
replace n_sold_`livestock'=medsold  if n_sold_`livestock'==.;
drop medpur medcons medsold;

*** Step 5: get the livestock revenue by animals on a yearly basis.
    We will calculate the herd value based on net of purchases, from sales 
    and consumption;

generate agliv_`livestock' = (n_sold_`livestock' + n_consum_`livestock') * price_s_`livestock' - n_purch_`livestock' * price_p_`livestock';
generate agcon_`livestock' = n_consum_`livestock' * price_s_`livestock';
replace agliv = agliv + agliv_`livestock';
replace agcon2 = agcon2 + agcon_`livestock';
macro shift;
		};
end;

aggregate_livestock cattle sheep goats pigs poultry;	
sum n_* pri* ag*;
sum agliv*;
sum agcon2*;

*** What about negative numbers ??
;
sum agliv if agliv<0;
sum agcon2 if agcon2<0;

** Make the livestock herdval monthly;

replace agliv=agliv/12;
replace agcon2=agcon2/12;

keep hhnumber agliv agcon2 distr ethnicity langua_hh loc_type loc_sec hhselec roma romaself flag oversamp *_milk *_eggs *_wool;
summarize;
sort hhnumber;


	
************* PART III: AGRICULTURE REVENUE FROM ANIMAL PRODUCTS *********;
* Calculate the income from animal products on monthly basis
  The Income will be equal to Sales + Given + Bartered 
  and the amount used for own consumption
;
capture program drop aggregate_animal_product;
program define aggregate_animal_product;
generate aganimp =  0;
generate agcon3  =  0;
while "`1'" != ""{
local product `1';
summarize qt_prod_`product' qt_ushh_`product' qt_sold_`product' qt_given_`product' qt_barte_`product' amt_sale_`product';

** step 1: get the mean and std. dev.;

replace qt_prod_`product' =0 if qt_prod_`product' ==.;
replace qt_ushh_`product' =0 if qt_ushh_`product' ==.;
replace qt_sold_`product' =0 if qt_sold_`product' ==.;
replace qt_given_`product' =0 if qt_given_`product' ==.;
replace qt_barte_`product' =0 if qt_barte_`product' ==.;
replace amt_sale_`product' =0 if amt_sale_`product' ==.;
replace unit_pric_`product' =0 if unit_pric_`product' ==.; 

replace qt_prod_`product' =. if qt_prod_`product' <0;
replace qt_ushh_`product' =. if qt_ushh_`product' <0;
replace qt_sold_`product' =. if qt_sold_`product' <0;
replace qt_given_`product' =. if qt_given_`product' <0;
replace qt_barte_`product' =. if qt_barte_`product' <0;
replace amt_sale_`product' =. if amt_sale_`product' <0;
replace unit_pric_`product' =. if unit_pric_`product' <0;
	  
egen mprice=mean(unit_pric_`product') if unit_pric_`product' >0;
egen sprice=sd(unit_pric_`product') if unit_pric_`product' >0;

;
** step 2: check for outliers;
gen flag1=1 if unit_pric_`product' > 4 * mprice & unit_pric_`product' !=.;
gen flag2=1 if unit_pric_`product' > mprice + 2 * sprice * unit_pric_`product' !=.;
tabulate flag1 flag2, miss;
drop mprice sprice;


** step 3: calculate the median prices by product;
egen medianp =median(unit_pric_`product') if unit_pric_`product' >0, by(loc_typ);
egen nmedianp=median(unit_pric_`product') if unit_pric_`product' >0;
summarize medianp nmedianp;

** step 4: replace outliers with missing values;
replace unit_pric_`product' =. if flag1==1 & flag2==1;
drop flag1 flag2;

** step 5: replace the missing with median prices;

replace unit_pric_`product' = medianp if unit_pric_`product' ==.;
replace unit_pric_`product' = nmedianp if unit_pric_`product' ==.;
drop medianp nmedianp;
*** Check for outliers in Hh use, salary and barter, by careful observation;

summarize  *_`product';

** Set outliers to missing - I do not see too many outliers for the
   time being - live it as is ;


*** Step 6: calculate the total revenue
            It includes the quantities sold bartered and given
            away. I assume that if it is not sold for cash it is sold
            for some other remuneration ;

generate revs_`product' = amt_sale_`product' if amt_sale_`product' > 0 & amt_sale_`product' !=.;
replace  revs_`product' =qt_sold_`product' * unit_pric_`product' if revs_`product' ==.;
replace  revs_`product' = 0 if revs_`product' ==.;

generate revb_`product' = qt_barte_`product' * unit_pric_`product';
replace  revb_`product' = 0 if revb_`product' ==.;

generate revg_`product' = qt_given_`product' * unit_pric_`product';
replace  revg_`product' = 0 if revg_`product' ==.;

gen revt_`product' = revs_`product' + revb_`product'+ revg_`product';
sum rev*;

generate home_`product' = qt_ushh_`product' * unit_pric_`product';
		replace  home_`product' = 0 if home_`product' ==.;
		replace aganimp =  aganimp + revt_`product';
replace agcon3  =  agcon3  + home_`product';
sum revt_`product';
sum revt_`product' if revt_`product' > 0;
drop revs_`product' revb_`product' revg_`product' qt_*_`product' whre_acq_`product' unit_pric_`product' amt_sale_`product';
sum home_`product' if home_`product' > 0;

*** Calculate the value of home consumption seperately;

summarize home_`product' if home_`product' > 0;
*summarize;
macro shift;
		};
end;
		

aggregate_animal_product milk eggs wool;
summarize;

sort hhnumber;
label data "Ag Income Livestock";
label variable agliv "Agriculture : Livestock Net sales";
label variable agcon2 "Agriculture : Livestock Home Consumption";
label variable aganimp "Agriculture : Anim Prod Sales";
label variable agcon3 "Agriculture : Anim Prod Home Consumption";

label data "Ag Income Animal Product";

save ../dta/livestockaggregate.dta, replace;

log close;
