#delimit ;

capture log close;
log using log using ..\log\SelfEmploymentAggregate.log,replace;
*************************************************************;
*                                                           *;
*    Name    : SelfEmployment.DO              V : 01              *;
*    Date    : July 26, 2001                               *;
*    Infile  : r6_4_1                                       *;
*    Outfile : SelfEmployment                                     *;
*                                                           *;
*    OBJECTIVE: Calculates Income from self-employment      *;
*                                                           *;
*                                                           *;                                                         *;
*************************************************************;


set more off;

use ../../datacheck\dta\r6_4_1.dta;
sort hhnumber idcode;
merge hhnumber idcode using ../../datacheck\dta\r1.dta;
keep if _merge==3;

**  This step calculates income from self-employment;

* step2: replace outliers i.e.,if a avariable is larger than "mean_vrb+sd_vrb*5" by ".";
;

***PROGRAM STEPS;

cap prog drop outliers;

prog define outliers;
	
	gen a=`1';
	replace a=. if `1'<0;
	egen mean_`2'= mean(a);
	egen sd_`2'=sd(a);
	replace `1' =. if `1'>mean_`2'+sd_`2'*5;
	replace `1'=mean_`2' if `1'<0;
	drop a;
	end;
		
outliers self_csh csh; 
outliers self_knd knd ;


sum self*;


** step 3: calculte the median values-by type of activity, age and locality;
egen medcash=median(self_csh), by(slf1_act slf2_act age_yrs gender);
egen medknd=median(self_knd), by(slf1_act slf2_act age_yrs gender);


*** step 3: replace the missing values with median values;
replace self_csh=medcash if self_csh==.|self_csh<0;
replace self_knd=medknd if self_knd==.|self_knd<0;

gen selfinc=self_csh+self_knd;
label variable selfinc "Income from self-employment";

keep hhnum idcode selfinc self_csh self_knd; 
list if self_c==. | self_k==.;
keep if self_c!=. & self_k!=.;
lab data "Self Employment Income";
sort hhnum idcode;
sum;
save ..\dta\SelfEmploymentAggregate, replace;

;


log close;
