#delimit ;
capture log close;
log using ../log/socialprogramaggregate.log,replace;

capture program drop catage;
program define catage;
   gen catage=0;
   replace catage=1 if age_y>15 & age_y<=24;
   replace catage=2 if age_y>25 & age_y<=34;
   replace catage=3 if age_y>35 & age_y<=54;
   replace catage=4 if age_y>55 & age_y<=70;
end;
*
**  This step calculates income from maternal and social program benefits;
*;
set more off;
clear;
use ../../datacheck/dta/r1.dta;
keep hhnumber idcode gender age_yrs hhm;
sort hhnumber idcode;
merge hhnumber idcode using ../../datacheck/dta/r8_6.dta;
tab _merge hhm, miss;
keep if _merge==3;
summarize;
drop _merge;

generate matben=b_amount;
replace matben =0 if matben ==.;
replace matben =. if matben <0;
label variable matben "monthly maternity benefits";

generate stipend=s_amount; /*actually nobody got stipend*/
replace stipend =0 if stipend ==.;
replace stipend =. if stipend <0;
label variable stipend "monthly stipend";

generate child6 = s_allow;
replace child6 =0 if child6 ==.;
replace child6 =. if child6 <0;
label variable stipend "monthly stipend";

*** we need to adjust for individuals whose benefits and stipends were
    stopped. so we will only take the number of months they got benefits 
    last year and multiply by the amount received in the last month and 
    then divide by 12, there are two cases here;
**There is no don't know/refusal to answer for maternity benefits. I take care of those for the
	  future use;
replace b_stopy =. if b_stopy <0 | b_stopy == 99; 
replace b_stopm =. if b_stopm <0 | b_stopm == 99; 
replace b_starty =. if b_starty <0 | b_starty == 99; 
replace b_startm =. if b_startm <0 | b_startm == 99; 
generate duration1 = b_stopm;
replace  duration1 = duration1 + 12 if b_stopy ==2001;
replace  duration1 = duration1 - b_startm if b_startm > 1999;
replace  duration1 = duration1 - 12 if b_starty ==2001;
replace  duration1 = 12 if duration1 ==. | duration1 > 12;
tab duration1;
list if duration1<0;
**No one received subsidy;
sum s_*;
generate duration2 = 0;

**step 1: check for outliers-no child allowance reported;
egen meanmat = mean(matben);
egen sdmat   = sd(matben);
generate flag1=1 if matben>meanmat + sdmat *10;
tab flag1;
egen meansti = mean(stipend);
egen sdsti   = sd(stipend);
generate flag2=1 if stipend > meansti + sdsti *10;
tab flag2;
egen meanchi = mean(child6);
egen sdchi   = sd(child6);
generate flag3=1 if child6 > meanchi + sdchi *10;
tab flag3;

** step 2: replace the outliers with missing values;
replace matben=. if flag1==1;
replace stipend=. if flag2==1;
replace child6=. if flag3==1;

** step 3:calculate the median values;
catage;
egen medbencg =median(matben), by(catage gender);
egen medben   =median(matben);
egen medsticg =median(stipend), by(catage gender);
egen medsti   =median(stipend);
egen medchicg =median(child6), by(catage gender);
egen medchi   =median(child6);

** step 4: replace the missing values with median values;
replace matben=medbencg if matben==.;
replace matben=medben   if matben==.;
replace stipend=medsticg if stipend==.;
replace stipend=medsti   if stipend==.;
replace child6 =medsticg if child6==.;
replace child6 =medsti   if child6==.;

** make it on monthly basis;
replace matben=matben*duration1/12;
replace stipend=stipend*duration2/12;

summarize ;
keep hhnum idcode matben stipend child6;
sort hhnum idcode;
save ../../../stata/income/dta/socialprogramaggregate.dta, replace;
log close;







