#delimit ;
capture log close;
log using ../../../../data/stata/income/log/totalincomeaggregate.log, replace;
set more off;

**** CONSTRUCT AN INDIVIDUAL LEVEL INCOME FILE  *******;
*    And then add the totals the other file     *;

clear;
use ../../datacheck/dta/r1.dta;
keep hhnumber idcode age_yrs gender hhm;
label data "Individual Income file";
sort hhnumber idcode; 
*save ../temp/dta/individualincometemporary.dta, replace;

capture program drop addindf;
program define addindf;
  merge hhnumber idcode using ../dta/`1'.dta;
  tab _merge;
  drop if _merge==2;
  drop _merge;
  mac shift;
  while "`1'"~="" {;
     replace `1'=0 if `1'==. ;
     mac shift;
  };
  sort hhnumber idcode;
end;  
  
addindf MainJobAggregate hours1 winc1 child1;
addindf SecondJobAggregate hours2 winc2 child2;
addindf SelfEmploymentAggregate selfinc;
addindf PublicPensionAggregate pubpen  child4;
addindf PrivatePensionAggregate privpen;
addindf SurvivorsPensionAggregate surpen; 
addindf DisabilityPensionAggregate dispen;
addindf UnemploymentBenefitsAggregate child5;
addindf SocialProgramAggregate matben stip child6;
addindf IndividualInkindBenefitsAggregate tran othben;

keep hhnumber idcode age_yrs gender hhm
     hours1 winc1 child1
     hours2 winc2 child2
     selfinc
     pubpen  child4
     privpen
     surpen
     dispen
     unemb child5
     matben stip child6
     tran othben;

summarize;
label data "Individual Income File";

** Calculate summaries for each individual  
   Note that we assumed that child allowance had already 
   included in the take home pay, but not in the calculation of
   amounts received by the individuals in case of the social 
   benefits;
gen child = child1 + child2 + child4 + child5 + child6;
gen wage  = winc1 + winc2;

lab var child "Total Child Allowance";
lab var wage  "Total Wage Income";

sort hhnumber idcode;
save ../dta/individualincomeaggregate.dta, replace;

** Check a few Curiosities
;
count if wage>0 & unemben>0;
count if wage>0 & pubpen>0;
count if self>0 & unemben>0;
count if self>0 & pubpen>0;
summarize;

** Create a household level income file
;
collapse  (sum) wage selfinc pubpen privpen surpen dispen unemb matben stip tran othben child, by (hhnumber); 
rename selfinc self;
rename privpen sb_penpr;
rename pubpen sb_penpb;
rename surpen sb_surv;
rename dispen sb_disab;
rename unemb  sb_unemp;
rename matben sb_mater;
rename stip   sb_stip;	
rename tran   sb_trans;
rename othben sb_other;
rename child  sb_child;
label variable wage     "Wage Income";
label variable self     "Self Employment Income";
label variable sb_penpr "Social Benefit: Pri. Pension";
label variable sb_penpb "Social Benefit: Pub Pension";
label variable sb_surv  "Social Benefit: Survival Pen";
label variable sb_disab "Social Benefit: Disability";
label variable sb_unemp "Social Benefit: Unemployemnt";
label variable sb_mater "Social Benefit: Maternal";
label variable sb_stip  "Social Benefit: Stipend";
label variable sb_trans "Social Benefit: Transport";
label variable sb_other "Social Benefit: Other including medical";
label variable sb_child "Social Benefit: Child Allowance";
sort hhnumber;
save ../temp/householdincometemporary.dta, replace;

****** First create the Household file with a few characteristics;
clear;
use ../../consumption/dta/strata.dta;
sort hhnumber;
keep hhnumber distr loc_typ;

** REMEMBER: Files are not same dimension.  
	     After each merge We need to set legimate zeros 
	     to that value and some apparent zeros to missing 
;
** Bring in AGRICULTURAL INCOME                            *
   in household level file CropAggregate(Sec 6.6.1) OtherFarmingAggregate(Sec 6.6.2) LiveStockAggregate(Sec 6.8) AgriculturalInputsAggregate(Sec 6.9)  
;

capture progam drop addhhf;
program define addhhf;
  while "`1'"~="" {;
     merge hhnumber using ../dta/`1'.dta;
     tab _merge;
     drop _merge;
     sort hhnumber;
     macro shift;
   };
end;

addhhf CropAggregate OtherFarmingAggregate LiveStockAggregate AgriculturalInputsAggregate;

sum;

** Calculate total Agriculture Income & costs:
   Note that income from livestock includes home consumption
;
generate aginc= agcrop + agcon1 + agliv + aganim + agcon3 + agoinc ;
generate aghcons= agcon1 + agcon2 + agcon3;
generate agcost = aginp  + aglab  + agfeed + agoc;
summarize aginc aghcons agcost;

label variable aginc  "Agriculture: total income";
label variable aghcon "Agriculture: total home consumption";
label variable agcost "Agriculture: total costs";

label data "Total Household income";
sort hhnumber;
des;
sum;
merge hhnumber using ../temp/householdincometemporary.dta;
tab _merge;
drop _merge;
sort hhnumber;

** BRING IN THE REST OF THE HOUSEHOLD LEVEL FILES  **
;
addhhf HouseholdBenefitsAggregate RemittancesReceivedAggregate RemittancesSentAggregate OtherRevenuesAggregate RealEstateAggregate;

** CALCULATE THE TOTALS  **
;
des;
sum;

** Note: Total income is equal to the sum of:
	 Net agricultural income 
	 wage income and self employement income
	 social benefit income (excluding Child allowance already
	   calculated in the several income sections
	 Net Remittances (A measure of disposable income does not include
	   the amount remitted to others)
	 Other revenue 
	 Rents from real estate assets
;
*** get the share of each category in the total income;
** see how many Hhsize_Resident have negetive income;

**** make three socail benefit variables: pensions, social insurance 
        and unemp benefits;

generate pension=sb_penpr + sb_penpb;
generate socins=sb_surv + sb_disab + sb_mater + sb_stip +
             sb_trans + sb_other + sb_hhold + sb_child;
generate unempben=sb_unemp;

label variable pension "pension:pub and priv";
label variable socins "social insurance";
label variable unempben "unemp benefits";
count if aginc==0 & aghcons==0 & agcost>0;

*** take a proportionate reduction in agcost from the ag sales  and
	  home cons variable;

*** there are 1391 cases where the aginc=0, so the ratio is set to zero;

** We want to develop two component of the total agricultural income, 
   namely sales and home concumption. To do that we will have to deduct
   the proportion of total costs accordingly. First we develop the 
   ratio variable, which tells us what portion of the total Ag. income
   is derived from home consumption. Then, we deduct that perecntage of
   the total cost from the home consumption income variable, and 
   likewise for sales;
	;
gen hhtminc= aginc - agcost + 
	     wage + self +
	     sb_penpr + sb_penpb + sb_surv +
	     sb_disab + sb_unemp + sb_mater + sb_stip +
	     sb_trans + sb_other + sb_hhold + sb_child+
	     remitr - remits +
	     othrev + assetinc ;

label variable hhtminc  "Total Hh Monthly Income";
** Check negetive values ;

count if hhtminc<0;
sum hhtminc if hhtminc>0,det;
generate ratio=aghcons/aginc;
replace ratio=0 if aginc==0;

generate cost_sal=agcost*(1-ratio);
generate cost_con=agcost*ratio;
generate agninc=aginc-aghcons-cost_sal;
label variable agninc "new ag income";

generate agncon=aghcons-cost_con;
label variable agncon "new home cons";


sum agninc agncon wage 
    self socins pension unempben hhtminc 
    remitr remits othrev assetinc if oversample !=1;

*sum agninc agncon wage 
    self socins pension unempben hhtminc 
    remitr remits othrev assetinc [w=hhsize_resident] if oversample !=1;


***** Note: we define the major source of income as the category 
            whose share of hhtminc income is greater than 50 percent, 
            however, there are some 391 Hhs in which case no category 
            has more than 50 percent share, and will be called
            as mixed households;

***** create a new total monthly income variable;
generate hhtminc2= agninc + agncon + 
              wage + self + socins + pension + unempben +
              remitr - remits +
              othrev + assetinc ;

label variable hhtminc "new: total HH monthly income";

summarize;

**** get the major source of income;

generate shagri = agninc*100/hhtminc2;
label variable shagri "Share of Agricultural Income";
generate shkind = agncon*100/hhtminc2;
label variable shkind "Share of In-kind Income";
generate shwage = wage*100/hhtminc2;
label variable shwage "Share of Wage Income (excl self-employment)";
generate shself = self*100/hhtminc2;
label variable shself "Share of Self-employment income"; 
generate shsoc  = socins*100/hhtminc2;
label variable shsoc "Share of Social Secial Insurance in income";
generate shpen  = pension*100/hhtminc2;
label variable shpen "Share of Pension in Income";
generate shunemp= unempben*100/hhtminc2;
label variable shunemp "Share of Unemployment Benefit in Income";
generate shremr = remitr*100/hhtminc2;
label variable shremr "Share of remittance received in Income";
generate shrems = remits*100/hhtminc2;
label variable shrems "Share of remittance sent in Incomereceived";
generate shremn = shremr - shrems; 
label variable shremn "Share of net remittance received";
generate shothr = othrev*100/hhtminc2;
label variable shothr "Share of net remittance received in Income";
generate shasset= assetinc*100/hhtminc2;
label variable shasset "Share of Asset Income";

format sh* %5.2f;


sort hhnumber;
save ../dta/householdincomeaggregate.dta, replace;

log close;







