#delimit ;
capture log close;
log using K:/BIHS01/Data/STATA/PROFILE/Log/HouseholdInformation.log, replace;
;
clear;
set more off;
set memory 20m;
************** SOURCE OF INCOME AND POVERTY *************
;
use K:/BIHS01/Data/STATA/PROFILE/Dta/PersonalInformation.dta, clear;
sort hhnumber;

generate temp1 = 1 if employment == 1;
by hhnumber:egen number_employed = count(temp1);  
drop temp1;
label variable number_employed "Number of employed people in household";
generate n_empl = number_employed;
replace  n_empl = 2 if n_empl >=3;
label define n_empl 0 "0" 1 "1" 2 "2+";
label values n_empl n_empl;

 
generate temp1 = 1 if employment == 0;
by hhnumber:egen byte number_unemployed = count(temp1);  
drop temp1;
label variable number_unemployed "Number of unemployed people in household";

generate temp1 = 1 if age_cluster == 0;
by hhnumber:egen byte number_children = count(temp1);  
drop temp1;
label variable number_children "Number of children in household";

generate temp1 = 1 if age_cluster == 1;
by hhnumber:egen byte number_workforce = count(temp1);  
drop temp1;
label variable number_workforce "Number of workforce in household";

generate temp1 = 1 if age_cluster == 2;
by hhnumber:egen byte number_elderly = count(temp1);  
drop temp1;
label variable number_elderly "Number of elderly people in household";
	
generate temp1 = 1 if age_yrs >=0 & age_yrs <=5;
by hhnumber:egen byte number_age0005 = count(temp1);  
drop temp1;
label variable number_age0005 "Number of people aged between 0 and 5 inclusive";

generate temp1 = 1 if age_yrs >=6 & age_yrs <=10;
by hhnumber:egen byte number_age0610 = count(temp1);  
drop temp1;
label variable number_age0610 "Number of people aged between 6 and 10 inclusive";
	
	
/*As of August 8, 2001, there are three problematic households;
Those are hhnumber = 466, 495 and 786. The first two households
have more than one household head and the last one has no household
head. This program assumes that the head of the household is the
person with idcode==1. This assumption is reasonable by circumstantial
evidences. The variable "householdhead" identifies the household head.*/	  

generate temp1 = 1 if relationship == 1;
by hhnumber:egen temp2 =  count(temp1); /*temp2: # household head (must be 1 if the record is correct. */
drop temp1;
sort hhnumber;
generate spouse = 0;
replace  spouse = 1 if relationship ==2;
	
generate byte householdhead = 1 if relationship ==1 & temp2 ==1; /*identifying household head*/
replace  householdhead = 1 if temp2 !=1 & idcode ==1;
replace  spouse = 1        if temp2 !=1 & idcode !=1 & relationship ==1;
drop temp2;
	
sort hhnumber;
by hhnumber: egen temp1 = sum(spouse); /*No household has more than one spouse*/
tabulate temp1;
generate hhsingle = (temp1 == 0);
	
generate hhgender = gender     if householdhead ==1;
generate hhage    = age_yrs    if householdhead ==1;
generate hheduc   = educ       if householdhead ==1;
generate hhempl   = employment if householdhead ==1;
generate hhyrsch  = yrschool   if householdhead ==1;

keep if householdhead ==1;
sort hhnumber idcode;
keep hhnumber hhgender hhage hheduc hhempl number_employed n_empl number_unemployed number_children number_workforce number_elderly hhyrsch hhsingle number_age0005 number_age0610;
label variable hhgender "Gender of Household Head";
label define hhgender 1 "Male" 2 "Female";
label values hhgender hhgender;
label variable hhage  "Age of Household Head";
label variable hheduc "Education level of Household Head";
label values hheduc educ;
label variable hhempl "Employment Status of Household Head";
label values hhempl employment;
label variable hhyrsch "Years of schooling for Household Head";
label variable hhsingle "Household head single?";
label define hhsingle 0 "Not single" 1 "Single";
label values hhsingle hhsingle;
sort hhnumber;
summarize;	
merge hhnumber using K:/BIHS01/Data/STATA/DATACHECK/Dta/r4.dta;
tabulate _merge;
drop _merge;
keep hhnumber hhgender hhage hheduc hhempl typ_wc hrs_elec hrs_h2o energy_c energy_h typ_wast q_fono n_rooms number_employed n_empl number_unemployed number_children number_workforce number_elderly hhyrsch hhsingle number_age0005 number_age0610;
summarize; /*no one refused to answer or said don't know to those variables*/	

sort hhnumber;
merge hhnumber using  K:/BIHS01/Data/STATA/INCOME/Dta/HouseholdIncomeAggregate.dta;
tabulate _merge;
drop _merge;

sort hhnumber;	
merge hhnumber using K:/BIHS01/Data/STATA/PROFILE/Dta/PovertyProfile.dta;
tabulate _merge;
drop _merge;
	
generate hhs = hhsize_resident;	
replace  hhs = 5 if hhsize_resident >= 5 & hhsize_resident !=.;
label variable hhs "Household Size";
label define hhs 1 "1" 2 "2" 3 "3" 4 "4" 5 "5+";
label values hhs hhs;
generate source_old =4;
generate overflow_old =0;
replace source_old=1 if shwage + shself > 50 & shwage !=. & shself !=.;
replace overflow_old = overflow_old + 1 if shwage+shself>50 & shwage!=. & shself!=.;
replace source_old=2 if shagri + shkind > 50 & shagri !=. & shkind !=.;
replace overflow_old = overflow_old + 1 if shagri+shkind>50 & shagri!=. & shkind!=.;
replace source_old=3 if shpen+shsoc+shunemp>50 & shpen!=. & shsoc!=. & shunemp !=.;
replace overflow_old = overflow_old + 1 if shpen+shsoc+shunemp>50 & shpen!=. & shsoc!=. & shunemp !=.;

label variable source_old "source of income1--old categorization";
label define source_old 1 "Earned income(wage+self)"
               2 "Agriculture(agri+inkind)" 
               3 "Social Benefits(incl pension and other social benefits)inkind" 
               4 "Mixed";
label values source_old source_old;
tab overflow_old;

generate source =5;
generate overflow =0;
replace source=1 if shwage + shself > 50 & shwage !=. & shself !=.;
replace overflow = overflow + 1 if shwage+shself>50 & shwage!=. & shself!=.;
replace source=2 if shagri + shkind > 50 & shagri !=. & shkind !=.;
replace overflow = overflow + 1 if shagri+shkind>50 & shagri!=. & shkind!=.;
replace source=3 if shpen>50;
replace overflow = overflow + 1 if shpen>50 & shpen!=.;
replace source=4 if shsoc+shunemp>50;
replace overflow = overflow + 1 if shsoc+shunemp>50 & shsoc!=. & shunemp !=.;

label variable source "source of income1--old categorization";
label define source 1 "Earned income(wage+self)"
               2 "Agriculture(agri+inkind)" 
               3 "Pension" 
               4 "Social Benefits(excl pension)"
               5 "Mixed";
label values source source;
tab overflow_old;

/*********CALCULATING HOUSING CHARACTERISTICS***/
gen electricity_availability=0 if hrs_elec<23;
replace electricity_availability=1 if hrs_elec>=23;
label variable electricity_availability "number of hours elec available";
label define electricity_availability 0 "<23 hrs" 1 ">=23 hrs";
label values electricity_availability electricity_availability;

gen water_availability=0 if hrs_h2o<23;
replace water_availability=1 if hrs_h2o>=23;
label variable water_availability "number of hours water available";
label define water_availability 0 "<23 hrs" 1 ">=23 hrs";
label values water_availability water_availability;

gen temporary = hhsize_resident/n_rooms; 
generate crowding = 2 if temporary >=2 & temporary !=.;
replace  crowding = 1 if temporary >=1 & temporary <2 & temporary !=.;
replace  crowding = 0 if temporary <1 & temporary !=.;
label variable crowding "Crowding measure: average number of people in a room in the hosuehold";
label define crowding 0 "0-1" 1 "1-2" 2 "2+";	
label values crowding crowding;

rename typ_wc toilet_type; 
rename energy_c cooking_energy;
rename energy_h heating_energy;
rename typ_wast disposal_system;	
rename q_fono   phone_availability;

/***********CALCULATING DEPENDENCE RATIO*****/
generate potential_dependency = (number_children + number_elderly) / number_workforce; /*this number is missing when nobody is between the age of 15 and 65*/
label variable potential_dependency "Dependency ratio: (#children+#elderly)/#workforce";	
generate actual_dependency = (number_children + number_elderly) / number_employed; /*this number is missing when nobody works in the hosuehold*/
label variable actual_dependency "Dependency ratio: (#children+#elderly)/#employed";	

keep hhnumber hhsize_resident hhs source source_old distr clust ethnicity ethnicity_adj langua_hh loc_type loc_sec roma romaself flag oversample exptot_d hhsize_all adulteq pcexp_d aeexp_d hhdecpc_d hhdecae_d popdecpc_d popdecae_d hhquipc_d hhquiae_d popquipc_d popquiae_d pcpoor_d pcp1_d pcp2_d povertyline hhgender hhage hheduc hhempl hhyrs toilet_type electricity_availability water_availability cooking_energy heating_energy disposal_system phone_availability crowding number_employed n_empl number_unemployed number_children number_workforce number_elderly potential_dependency actual_dependency hhtminc hhtminc2 hhsingle sh* number_age0005 number_age0610;
order hhnumber hhsize_resident hhs source source_old distr clust ethnicity ethnicity_adj langua_hh loc_type loc_sec roma romaself flag oversample exptot_d hhsize_all adulteq pcexp_d aeexp_d hhdecpc_d hhdecae_d popdecpc_d popdecae_d hhquipc_d hhquiae_d popquipc_d popquiae_d pcpoor_d pcp1_d pcp2_d povertyline hhgender hhage hheduc hhempl hhyrs toilet_type electricity_availability water_availability cooking_energy heating_energy disposal_system phone_availability crowding number_employed n_empl number_unemployed number_children number_workforce number_elderly potential_dependency actual_dependency hhtminc hhtminc2 hhsingle sh* number_age0005 number_age0610;

sort hhnumber;
merge hhnumber using K:/BIHS01/Data/STATA/PROFILE/Dta/AssetProfile.dta;
tabulate _merge;
drop _merge;
sort hhnumber;	
label data "Household Information";
save K:/BIHS01/Data/STATA/PROFILE/Dta/HouseholdInformation.dta, replace;
log close;

/*
generate source=5;
replace source=1 if shwage+shself>50;
replace  overflow =1 if shwage+shself>50 & shwage!=. & shself!=.;
replace source=2 if shagri>50;
replace  overflow = overflow + 1 if shagri>50 & shagri!=.;
replace source=3 if shkind>50;
replace  overflow = overflow + 1 if shkind>50 & shkind!=.;
yreplace source=4 if shpen+shsoc+shunemp>50;
replace  overflow = overflow + 1 if  shpen+shsoc+shunemp>50 & shpen!=.;
*list sh* if overflow>1;
	tab overflow;
tab loc_type source if overflow>1;	
label variable source "source of income";
label define source 1 "earned inc" 
               2 "agri" 
               3 "inkind" 
               4 "social assistance"
               5 "mixed" ;
label values source source;
*/
