#delimit ;
capture log close;
log using K:/BIHS01/Data/STATA/PROFILE/log/PersonalInformation.log, replace;
clear;
set more off;
set memory 20m;
********************************;
*** Part 1: EDUCATION **********;
********************************;

use K:/BIHS01/Data/STATA/DATACHECK/dta/r1.dta;
keep hhnumber idcode hhm age_yrs age_mth gender relationship;
sort hhnum idcode;
*** Bring in the education file;

merge hhnumber idcode using K:/BIHS01/Data/STATA/DATACHECK/dta/r3.dta;
tab _merge;
generate byte r3=0;
replace r3=1 if _merge==3;
label variable r3 "Flag if record in Section 3 exists for the person";
label define r3 0 "Record not exist in r3" 1 "Record exists in r3";
label values r3 r3;
drop _merge;
*keep if _merge==3;
	
/*A correction of age_yrs. When age_yrs is missing, age_mth is not missing.
We assume that age_yrs==0 in this case.*/	  
replace age_yrs =0 if age_yrs ==. & age_mth !=.;
	  
keep hhnumber hhm idcode relationship age_yrs gender q_attend ed_level yrs_educ why_stop r3;
sum;

*** Make age-group categories;
generate byte agroup=1 if age_yrs>=0 & age_yrs<5;
replace  agroup=2 if age_yrs>=5 & age_yrs<=10;
replace  agroup=3 if age_yrs>10 & age_yrs<=17;
replace  agroup=4 if age_yrs>17 & age_yrs<=21;
replace  agroup=5 if age_yrs>21 & age_yrs<=25;
replace  agroup=6 if age_yrs>25 & age_yrs<=45;
replace  agroup=7 if age_yrs>45 & age_yrs<=55;
replace  agroup=8 if age_yrs>55;
replace  agroup=. if age_yrs<0 | age_yrs ==.;
label variable agroup "age_groups";

label define agroup 1 "less than 5" 
               2 "5-10 yrs" 
               3 "11-21 yrs"
            	4 "18-25 yrs" 
               5 "22-25 yrs"
               6 "26-45 yrs" 
               7 "46-55 yrs" 
               8 "above 55";
label values agroup agroup;

****** CREATING NUMBER OF YEARS OF SCHOOLING;

generate yrschool=0 if ed_level!=.;
replace  yrschool=1 if ed_level==31;
replace  yrschool=2 if ed_level==32;
replace  yrschool=3 if ed_level==33;
replace  yrschool=4 if ed_level==34;

replace  yrschool=5 if ed_level==41;
replace  yrschool=6 if ed_level==42;
replace  yrschool=7 if ed_level==43;
replace  yrschool=8 if ed_level==44;

replace  yrschool=9 if ed_level==51;
replace  yrschool=10 if ed_level==52;
replace  yrschool=11 if ed_level==53;

replace  yrschool=12 if ed_level==61;
replace  yrschool=13 if ed_level==62;
replace  yrschool=14 if ed_level==63;
replace  yrschool=15 if ed_level==64;
replace  yrschool=16 if ed_level==65;

replace  yrschool=12 if ed_level==71;
replace  yrschool=13 if ed_level==72;
replace  yrschool=14 if ed_level==73;
replace  yrschool=15 if ed_level==74;
replace  yrschool=16 if ed_level==75;

replace  yrschool=17 if ed_level==81;
replace  yrschool=18 if ed_level==82;
replace  yrschool=19 if ed_level==83;
replace  yrschool=20 if ed_level==84;
replace  yrschool=21 if ed_level==85;
*** assuming 6 years for >= 6 years of university;
replace  yrschool=22 if ed_level==86;
*** assuming 3 years postgraduate studies after 5 years of university;
replace  yrschool=24 if ed_level==87;
*** assuming right after general secondary school;
replace  yrschool=12 if ed_level==91;
replace  yrschool=13 if ed_level==92;
replace  yrschool=14 if ed_level==93;

label variable yrschool "Years of schooling";
	
****CREATING VARIABLE FOR EDUCATIONAL ATTAINMENT;
**** Note: The secondary education level includes general, 
           technical and vocational level of education;
*** Make five levels of education;
generate byte educ=0 if ed_level >=0 & ed_level<=1;
replace  educ=1 if ed_level>1 & ed_level<=34;
replace  educ=2 if ed_level>=41 & ed_level<=44;
replace  educ=3 if ed_level>=51 & ed_level<=75;
replace  educ=4 if ed_level>=81;
replace  educ=. if ed_level<0;
list hhnumber idcode ed_level if educ==.;
label variable educ "educ. level";

label define educ 0 "no education" 
                  1 "primary" 
                  2 "middle" 
                  3 "Secndry" 
                  4 "Univ & higher";
label values educ educ;
drop ed_level;

****CREATING DUMMY VARIABLES FOR ELDERLY PEOPLE, CHILDREN AND SO FORTH**;
generate byte age_cluster = 0 if (age_yrs >=0) & (age_yrs <= 15) & (age_yrs != .);
replace       age_cluster = 1 if (age_yrs > 15) & (age_yrs < 65) & (age_yrs != .);
replace       age_cluster = 2 if (age_yrs >= 65) & (age_yrs != .);
label variable age_cluster "Age cluster (Child/Workforce/Elderly)";
label define age_cluster 0 "Child(15-)" 1 "Work Force(16-64)" 2 "Elderly(65+)";
label values age_cluster age_cluster;
sort hhnumber idcode;
merge hhnumber idcode using K:/BIHS01/Data/STATA/Profile/Dta/EmploymentProfile.dta;
tabulate _merge;
drop _merge;
sort hhnumber idcode;
merge hhnumber idcode using K:/BIHS01/Data/STATA/Profile/Dta/SocialAssistanceProfile.dta;
tabulate _merge;
drop _merge;
drop if hhm != 1;
summarize;
describe;
label data "Personal Information";
sort hhnumber idcode;	
save K:/BIHS01/Data/STATA/PROFILE/Dta/PersonalInformation.dta,replace;
log close;
exit, clear;



