#delimit ;
clear;
set more off;
log using ../log/assetprofile.log,replace;
capture program drop import;	
program define import;
local variable `1';
local file `2';
sort hhnumber;
merge hhnumber using `2';
replace own_`variable' =0 if own_`variable' ==.;
drop _merge;
end;

/*Real Assets*/
use "../../datacheck/dta/r9_2.dta", clear;
/*There are three instances for which property type (q3) is zero.
Those observations contain no substantial information. We just ignore them*/
list if p_typ==0;
drop if p_typ==0;
sort hhnumber;
by hhnumber: generate byte own_realasset = _n;
keep if own_realasset == 1;
label variable own_realasset "Ownership of real assets other than the properties in current use by the household";
label define own_realasset 0 "No real assets" 1 "Own real assets";
label values own_realasset own_realasset; 
keep hhnumber own_realasset;
sort hhnumber;
tempfile realasset;
save `realasset';
clear;

/*Livestocks*/
use "../../datacheck/dta/r6_8.dta", clear;
keep hhnumber n_owned_*;
replace n_owned_cattle =1 if n_owned_cattle <0;
replace n_owned_sheep  =1 if n_owned_sheep  <0;
replace n_owned_goats  =1 if n_owned_goats  <0;
replace n_owned_pigs   =1 if n_owned_pigs   <0;
replace n_owned_poultry=1 if n_owned_poultry<0;
egen temp = rsum(n_owned_cattle n_owned_sheep n_owned_goats n_owned_pigs n_owned_poultry);
generate byte own_livestock = (temp >0);
drop temp;
tabulate own_livestock;
keep hhnumber own_livestock;
label variable own_livestock "Ownership of Livestocks";
label define own_livestock 0 "No livestocks" 1 "Own real assets";
label values own_livestock own_livestock; 
sort hhnumber;
tempfile livestock;
save `livestock';

/*Crops*/
use "../../datacheck/dta/r6_6_1.dta", clear;
drop if crop ==0;
keep hhnumber crop;
sort hhnumber;
by hhnumber: generate byte own_crop = _n;
keep if own_crop ==1;
label variable own_crop "Ownership of crops";
label define own_crop 0 "No Crops" 1 "Own crops";
label values own_crop own_crop;
keep hhnumber own_crop;
sort hhnumber;
tempfile crop;	  
save `crop';

use "../../datacheck/dta/r4.dta", clear;
generate byte own_dwelling = (rent_sta==1); /*no missing records*/
keep hhnumber own_dwelling;
label variable own_dwelling "Ownership of own dwelling";
label define own_dwelling 0 "Not have own dwelling" 1 "Have own dwelling";
label values own_dwelling own_dwelling;
label data "AssetProfile";
import crop `crop';
import livestock `livestock';
import realasset `realasset';
sort hhnumber;
describe;
summarize;	
save ../dta/assetprofile.dta, replace;
log close;
exit, clear;	
